<?php

defined( 'ABSPATH' ) or die;

$GLOBALS['processed_terms'] = array();
$GLOBALS['processed_posts'] = array();

require_once ABSPATH . 'wp-admin/includes/post.php';
require_once ABSPATH . 'wp-admin/includes/taxonomy.php';
require_once ABSPATH . 'wp-admin/includes/image.php';

function themify_import_post( $post ) {
	global $processed_posts, $processed_terms;

	if ( ! post_type_exists( $post['post_type'] ) ) {
		return;
	}

	/* Menu items don't have reliable post_title, skip the post_exists check */
	if( $post['post_type'] !== 'nav_menu_item' ) {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
		if ( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
			$processed_posts[ intval( $post['ID'] ) ] = intval( $post_exists );
			return;
		}
	}

	if( $post['post_type'] == 'nav_menu_item' ) {
		if( ! isset( $post['tax_input']['nav_menu'] ) || ! term_exists( $post['tax_input']['nav_menu'], 'nav_menu' ) ) {
			return;
		}
		$_menu_item_type = $post['meta_input']['_menu_item_type'];
		$_menu_item_object_id = $post['meta_input']['_menu_item_object_id'];

		if ( 'taxonomy' == $_menu_item_type && isset( $processed_terms[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_terms[ intval( $_menu_item_object_id ) ];
		} else if ( 'post_type' == $_menu_item_type && isset( $processed_posts[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_posts[ intval( $_menu_item_object_id ) ];
		} else if ( 'custom' != $_menu_item_type ) {
			// associated object is missing or not imported yet, we'll retry later
			// $missing_menu_items[] = $item;
			return;
		}
	}

	$post_parent = ( $post['post_type'] == 'nav_menu_item' ) ? $post['meta_input']['_menu_item_menu_item_parent'] : (int) $post['post_parent'];
	$post['post_parent'] = 0;
	if ( $post_parent ) {
		// if we already know the parent, map it to the new local ID
		if ( isset( $processed_posts[ $post_parent ] ) ) {
			if( $post['post_type'] == 'nav_menu_item' ) {
				$post['meta_input']['_menu_item_menu_item_parent'] = $processed_posts[ $post_parent ];
			} else {
				$post['post_parent'] = $processed_posts[ $post_parent ];
			}
		}
	}

	/**
	 * for hierarchical taxonomies, IDs must be used so wp_set_post_terms can function properly
	 * convert term slugs to IDs for hierarchical taxonomies
	 */
	if( ! empty( $post['tax_input'] ) ) {
		foreach( $post['tax_input'] as $tax => $terms ) {
			if( is_taxonomy_hierarchical( $tax ) ) {
				$terms = explode( ', ', $terms );
				$post['tax_input'][ $tax ] = array_map( 'themify_get_term_id_by_slug', $terms, array_fill( 0, count( $terms ), $tax ) );
			}
		}
	}

	$post['post_author'] = (int) get_current_user_id();
	$post['post_status'] = 'publish';

	$old_id = $post['ID'];

	unset( $post['ID'] );
	$post_id = wp_insert_post( $post, true );
	if( is_wp_error( $post_id ) ) {
		return false;
	} else {
		$processed_posts[ $old_id ] = $post_id;

		if( isset( $post['has_thumbnail'] ) && $post['has_thumbnail'] ) {
			$placeholder = themify_get_placeholder_image();
			if( ! is_wp_error( $placeholder ) ) {
				set_post_thumbnail( $post_id, $placeholder );
			}
		}

		return $post_id;
	}
}

function themify_get_placeholder_image() {
	static $placeholder_image = null;

	if( $placeholder_image == null ) {
		if ( ! function_exists( 'WP_Filesystem' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php';
		}
		WP_Filesystem();
		global $wp_filesystem;
		$upload = wp_upload_bits( $post['post_name'] . '.jpg', null, $wp_filesystem->get_contents( THEMIFY_DIR . '/img/image-placeholder.jpg' ) );

		if ( $info = wp_check_filetype( $upload['file'] ) )
			$post['post_mime_type'] = $info['type'];
		else
			return new WP_Error( 'attachment_processing_error', __( 'Invalid file type', 'themify' ) );

		$post['guid'] = $upload['url'];
		$post_id = wp_insert_attachment( $post, $upload['file'] );
		wp_update_attachment_metadata( $post_id, wp_generate_attachment_metadata( $post_id, $upload['file'] ) );

		$placeholder_image = $post_id;
	}

	return $placeholder_image;
}

function themify_import_term( $term ) {
	global $processed_terms;

	if( $term_id = term_exists( $term['slug'], $term['taxonomy'] ) ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term['term_id'] ) )
			$processed_terms[ intval( $term['term_id'] ) ] = (int) $term_id;
		return (int) $term_id;
	}

	if ( empty( $term['parent'] ) ) {
		$parent = 0;
	} else {
		$parent = term_exists( $term['parent'], $term['taxonomy'] );
		if ( is_array( $parent ) ) $parent = $parent['term_id'];
	}

	$id = wp_insert_term( $term['name'], $term['taxonomy'], array(
		'parent' => $parent,
		'slug' => $term['slug'],
		'description' => $term['description'],
	) );
	if ( ! is_wp_error( $id ) ) {
		if ( isset( $term['term_id'] ) ) {
			$processed_terms[ intval($term['term_id']) ] = $id['term_id'];
			return $term['term_id'];
		}
	}

	return false;
}

function themify_get_term_id_by_slug( $slug, $tax ) {
	$term = get_term_by( 'slug', $slug, $tax );
	if( $term ) {
		return $term->term_id;
	}

	return false;
}

function themify_undo_import_term( $term ) {
	$term_id = term_exists( $term['slug'], $term['taxonomy'] );
	if ( $term_id ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term_id ) ) {
			wp_delete_term( $term_id, $term['taxonomy'] );
		}
	}
}

/**
 * Determine if a post exists based on title, content, and date
 *
 * @global wpdb $wpdb WordPress database abstraction object.
 *
 * @param array $args array of database parameters to check
 * @return int Post ID if post exists, 0 otherwise.
 */
function themify_post_exists( $args = array() ) {
	global $wpdb;

	$query = "SELECT ID FROM $wpdb->posts WHERE 1=1";
	$db_args = array();

	foreach ( $args as $key => $value ) {
		$value = wp_unslash( sanitize_post_field( $key, $value, 0, 'db' ) );
		if( ! empty( $value ) ) {
			$query .= ' AND ' . $key . ' = %s';
			$db_args[] = $value;
		}
	}

	if ( !empty ( $args ) )
		return (int) $wpdb->get_var( $wpdb->prepare($query, $args) );

	return 0;
}

function themify_undo_import_post( $post ) {
	if( $post['post_type'] == 'nav_menu_item' ) {
		$post_exists = themify_post_exists( array(
			'post_name' => $post['post_name'],
			'post_modified' => $post['post_date'],
			'post_type' => 'nav_menu_item',
		) );
	} else {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
	}
	if( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
		/**
		 * check if the post has been modified, if so leave it be
		 *
		 * NOTE: posts are imported using wp_insert_post() which modifies post_modified field
		 * to be the same as post_date, hence to check if the post has been modified,
		 * the post_modified field is compared against post_date in the original post.
		 */
		if( $post['post_date'] == get_post_field( 'post_modified', $post_exists ) ) {
			wp_delete_post( $post_exists, true ); // true: bypass trash
		}
	}
}

function themify_do_demo_import() {

	if ( isset( $GLOBALS["ThemifyBuilder_Data_Manager"] ) ) {
		remove_action( "save_post", array( $GLOBALS["ThemifyBuilder_Data_Manager"], "save_builder_text_only"), 10, 3 );
	}
$term = array (
  'term_id' => 8,
  'name' => 'Blog',
  'slug' => 'blog',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 15,
  'name' => 'News',
  'slug' => 'news',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 16,
  'name' => 'Sports',
  'slug' => 'sports',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 15,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 20,
  'name' => 'World',
  'slug' => 'world',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 15,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 21,
  'name' => 'Culture',
  'slug' => 'culture',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 15,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 22,
  'name' => 'Lifestyle',
  'slug' => 'lifestyle',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 15,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 6,
  'name' => 'Services',
  'slug' => 'services',
  'term_group' => 0,
  'taxonomy' => 'highlight-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 28,
  'name' => 'Features',
  'slug' => 'features',
  'term_group' => 0,
  'taxonomy' => 'highlight-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 45,
  'name' => 'Uncategorized',
  'slug' => 'uncategorized',
  'term_group' => 0,
  'taxonomy' => 'team-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 12,
  'name' => 'Company Timeline',
  'slug' => 'company-timeline',
  'term_group' => 0,
  'taxonomy' => 'timeline-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 13,
  'name' => 'Personal Timeline',
  'slug' => 'personal-timeline',
  'term_group' => 0,
  'taxonomy' => 'timeline-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 33,
  'name' => 'Team',
  'slug' => 'team',
  'term_group' => 0,
  'taxonomy' => 'testimonial-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 34,
  'name' => 'Testimonials',
  'slug' => 'testimonials',
  'term_group' => 0,
  'taxonomy' => 'testimonial-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 46,
  'name' => 'Uncategorized',
  'slug' => 'uncategorized',
  'term_group' => 0,
  'taxonomy' => 'testimonial-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 9,
  'name' => 'Photos',
  'slug' => 'photos',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 10,
  'name' => 'Videos',
  'slug' => 'videos',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 36,
  'name' => 'Vintage',
  'slug' => 'vintage',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 48,
  'name' => 'Featured',
  'slug' => 'featured',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 40,
  'name' => 'Single Page Menu',
  'slug' => 'single-page-menu',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$post = array (
  'ID' => 79,
  'post_date' => '2013-07-12 06:15:51',
  'post_date_gmt' => '2013-07-12 06:15:51',
  'post_content' => 'Maecenas tincidunt congue purus. Donec fringilla felis vel dolor consectetur, vel gravida quam molestie. Curabitur ut orci a sapien feugiat auctor in sit amet nisl. Morbi justo metus, dapibus a dignissim a, accumsan sit amet odio.

Duis venenatis at diam sed aliquet. Nunc interdum odio et nibh euismod laoreet. Sed non ultrices dui, sit amet adipiscing libero. Maecenas accumsan quam eleifend quam facilisis, sit amet aliquet neque mollis. Cras sit amet sollicitudin sem. Sed tincidunt rhoncus urna a pretium. Interdum et malesuada fames ac ante ipsum primis in faucibus. Pellentesque malesuada accumsan ante ac imperdiet. Quisque eu elementum urna. Maecenas venenatis imperdiet enim at bibendum. Duis eget convallis felis, id sollicitudin mauris. Nam sem metus, sagittis non feugiat vel, porttitor eu arcu. Sed dictum, nulla ac laoreet accumsan, dui sapien vestibulum nibh, in pharetra dolor dui eu erat. Ut feugiat dictum egestas. Nam eget arcu quis mauris imperdiet pulvinar.',
  'post_title' => 'Classic Car on the Beach',
  'post_excerpt' => '',
  'post_name' => 'car',
  'post_modified' => '2017-08-21 11:31:36',
  'post_modified_gmt' => '2017-08-21 11:31:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=79',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 82,
  'post_date' => '2013-07-12 06:24:06',
  'post_date_gmt' => '2013-07-12 06:24:06',
  'post_content' => 'Maecenas tincidunt congue purus. Donec fringilla felis vel dolor consectetur, vel gravida quam molestie. Curabitur ut orci a sapien feugiat auctor in sit amet nisl. Morbi justo metus, dapibus a dignissim a, accumsan sit amet odio.

Duis venenatis at diam sed aliquet. Nunc interdum odio et nibh euismod laoreet. Sed non ultrices dui, sit amet adipiscing libero. Maecenas accumsan quam eleifend quam facilisis, sit amet aliquet neque mollis. Cras sit amet sollicitudin sem. Sed tincidunt rhoncus urna a pretium. Interdum et malesuada fames ac ante ipsum primis in faucibus. Pellentesque malesuada accumsan ante ac imperdiet. Quisque eu elementum urna. Maecenas venenatis imperdiet enim at bibendum. Duis eget convallis felis, id sollicitudin mauris. Nam sem metus, sagittis non feugiat vel, porttitor eu arcu. Sed dictum, nulla ac laoreet accumsan, dui sapien vestibulum nibh, in pharetra dolor dui eu erat. Ut feugiat dictum egestas. Nam eget arcu quis mauris imperdiet pulvinar.',
  'post_title' => 'Meet My Best Friend',
  'post_excerpt' => '',
  'post_name' => 'meet-my-best-friend',
  'post_modified' => '2017-08-21 11:31:32',
  'post_modified_gmt' => '2017-08-21 11:31:32',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=82',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 84,
  'post_date' => '2013-07-12 06:19:32',
  'post_date_gmt' => '2013-07-12 06:19:32',
  'post_content' => 'Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Fusce tristique placerat nisi et ultricies. Aliquam orci nisl, cursus vitae venenatis sit amet, laoreet in lacus. Integer ac ullamcorper sem, vel auctor ante. Interdum et malesuada fames ac ante ipsum primis in faucibus. Nulla mattis, erat sit amet pellentesque blandit, libero augue sollicitudin leo, a convallis diam purus sit amet nibh. Sed condimentum blandit nibh in semper.

Vestibulum dignissim rutrum porttitor. Curabitur lacinia, arcu sed sollicitudin semper, sem enim faucibus velit, non scelerisque enim justo et tortor. Phasellus accumsan iaculis augue, sit amet sodales mi egestas nec. Phasellus in sagittis ipsum. Morbi elementum magna et ligula tincidunt, sit amet vestibulum nibh posuere. Ut facilisis felis in tortor feugiat, ac pretium enim tempus. Praesent volutpat, lacus sed congue hendrerit, justo risus venenatis massa, non fringilla velit metus ut lacus. Maecenas tincidunt congue purus. Donec fringilla felis vel dolor consectetur, vel gravida quam molestie. Curabitur ut orci a sapien feugiat auctor in sit amet nisl. Morbi justo metus, dapibus a dignissim a, accumsan sit amet odio.',
  'post_title' => 'Miniature City',
  'post_excerpt' => '',
  'post_name' => 'miniature-city',
  'post_modified' => '2017-08-21 11:31:34',
  'post_modified_gmt' => '2017-08-21 11:31:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=84',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1819,
  'post_date' => '2008-06-26 00:58:12',
  'post_date_gmt' => '2008-06-26 00:58:12',
  'post_content' => 'hasellus at nibh in erat rhoncus ornare. In convallis quis est fermentum sollicitudin. Phasellus nec purus elit. Aenean tempus tincidunt dolor, quis auctor diam auctor non.',
  'post_title' => 'Football League',
  'post_excerpt' => '',
  'post_name' => 'football-league',
  'post_modified' => '2017-08-21 11:31:58',
  'post_modified_gmt' => '2017-08-21 11:31:58',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1819',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'sports',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1828,
  'post_date' => '2008-06-26 01:21:13',
  'post_date_gmt' => '2008-06-26 01:21:13',
  'post_content' => 'Aliquam mattis mauris a sapien tincidunt, ac vestibulum urna porta. Aenean aliquet vulputate lacus vel venenatis. Etiam lorem sapien, vestibulum ut nisl sed, egestas dignissim enim.',
  'post_title' => 'From the Marathon',
  'post_excerpt' => '',
  'post_name' => 'from-the-marathon',
  'post_modified' => '2017-08-21 11:31:56',
  'post_modified_gmt' => '2017-08-21 11:31:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1828',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'sports',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1833,
  'post_date' => '2008-06-26 01:30:51',
  'post_date_gmt' => '2008-06-26 01:30:51',
  'post_content' => 'Etiam lorem sapien, vestibulum ut nisl sed, egestas dignissim enim. Nam lacus massa, pellentesque eget pulvinar vitae, sagittis eget justo. Maecenas bibendum sit amet odio et sodales. Praesent cursus mattis tortor, ut vestibulum purus venenatis at.',
  'post_title' => 'Watercolor',
  'post_excerpt' => '',
  'post_name' => 'watercolor',
  'post_modified' => '2017-08-21 11:31:55',
  'post_modified_gmt' => '2017-08-21 11:31:55',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1833',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'culture',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1822,
  'post_date' => '2008-06-26 23:38:36',
  'post_date_gmt' => '2008-06-26 23:38:36',
  'post_content' => 'Donec auctor consectetur tellus, in hendrerit urna vulputate non. Ut elementum fringilla purus. Nam dui erat, porta eu gravida sit amet, ornare sit amet sem.',
  'post_title' => 'Dirt Championship',
  'post_excerpt' => '',
  'post_name' => 'dirt-championship',
  'post_modified' => '2017-08-21 11:31:38',
  'post_modified_gmt' => '2017-08-21 11:31:38',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1822',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'sports',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1836,
  'post_date' => '2008-06-26 01:31:26',
  'post_date_gmt' => '2008-06-26 01:31:26',
  'post_content' => 'Cras tristique feugiat neque sed vestibulum. Sed eu urna quis lacus aliquet fermentum vel sed risus. Integer laoreet pretium interdum. Proin consequat consequat feugiat. Integer pellentesque faucibus aliquet.',
  'post_title' => 'Living Art',
  'post_excerpt' => '',
  'post_name' => 'living-art',
  'post_modified' => '2017-08-21 11:31:53',
  'post_modified_gmt' => '2017-08-21 11:31:53',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1836',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'culture',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1839,
  'post_date' => '2008-06-26 01:33:00',
  'post_date_gmt' => '2008-06-26 01:33:00',
  'post_content' => 'In convallis quis est fermentum sollicitudin. Phasellus nec purus elit. Aenean tempus tincidunt dolor, quis auctor diam auctor non. Quisque at fermentum purus, a aliquet arcu.',
  'post_title' => 'Long Exposures',
  'post_excerpt' => '',
  'post_name' => 'long-exposures',
  'post_modified' => '2017-08-21 11:31:52',
  'post_modified_gmt' => '2017-08-21 11:31:52',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1839',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'culture',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1845,
  'post_date' => '2008-06-26 01:36:35',
  'post_date_gmt' => '2008-06-26 01:36:35',
  'post_content' => 'Donec hendrerit, lectus in dapibus consequat, libero arcu dignissim turpis, id dictum odio felis eget ante. In ullamcorper pulvinar rutrum. In id neque pulvinar, tempor orci ac, tincidunt libero. Fusce ultricies arcu at mauris semper bibendum.',
  'post_title' => 'Cooking Courses',
  'post_excerpt' => '',
  'post_name' => 'cooking-courses',
  'post_modified' => '2017-08-21 11:31:50',
  'post_modified_gmt' => '2017-08-21 11:31:50',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1845',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'world',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1849,
  'post_date' => '2008-06-26 01:38:43',
  'post_date_gmt' => '2008-06-26 01:38:43',
  'post_content' => 'Phasellus dui erat, tincidunt pulvinar tempor at, lacinia eu lacus. Aenean euismod tellus laoreet turpis viverra facilisis. Nunc eu viverra eros, et facilisis dui. Sed pretium id risus eu tincidunt.',
  'post_title' => 'Maritime Shipping',
  'post_excerpt' => '',
  'post_name' => 'maritime-shipping',
  'post_modified' => '2017-08-21 11:31:48',
  'post_modified_gmt' => '2017-08-21 11:31:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1849',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'world',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1852,
  'post_date' => '2008-06-26 01:42:25',
  'post_date_gmt' => '2008-06-26 01:42:25',
  'post_content' => 'In lobortis vehicula lectus, et venenatis velit euismod sit amet. Morbi egestas malesuada turpis, dictum consequat mauris scelerisque ac. Mauris luctus commodo lorem, pulvinar sollicitudin ante porttitor id.',
  'post_title' => 'Water Town',
  'post_excerpt' => '',
  'post_name' => 'water-town',
  'post_modified' => '2017-08-21 11:31:47',
  'post_modified_gmt' => '2017-08-21 11:31:47',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1852',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'world',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1857,
  'post_date' => '2008-06-26 02:46:21',
  'post_date_gmt' => '2008-06-26 02:46:21',
  'post_content' => 'Nullam fringilla facilisis ultricies. Ut volutpat ultricies rutrum. In laoreet, nunc et auctor condimentum, enim lacus lacinia dolor, non accumsan leo nisl id lorem. Duis vehicula et turpis fringilla hendrerit.',
  'post_title' => 'Remote Places',
  'post_excerpt' => '',
  'post_name' => 'remote-places',
  'post_modified' => '2017-08-21 11:31:45',
  'post_modified_gmt' => '2017-08-21 11:31:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1857',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'lifestyle',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1860,
  'post_date' => '2008-06-26 02:47:20',
  'post_date_gmt' => '2008-06-26 02:47:20',
  'post_content' => 'Duis eget tellus nisl. Donec porta orci vel iaculis porta. Vivamus aliquet, ligula et tempus mattis, tortor ipsum eleifend massa, ac gravida dui est quis dui.',
  'post_title' => 'Evening Rides',
  'post_excerpt' => '',
  'post_name' => 'evening-rides',
  'post_modified' => '2017-08-21 11:31:43',
  'post_modified_gmt' => '2017-08-21 11:31:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1860',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'lifestyle',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1863,
  'post_date' => '2008-06-26 02:48:34',
  'post_date_gmt' => '2008-06-26 02:48:34',
  'post_content' => 'Proin vitae lectus eu turpis sollicitudin sagittis. Aliquam nunc odio, semper lacinia tincidunt a, dapibus vitae dolor. Class aptent taciti sociosqu ad litora torquent per conubia.',
  'post_title' => 'Learn Something New',
  'post_excerpt' => '',
  'post_name' => 'learn-something-new',
  'post_modified' => '2017-08-21 11:31:41',
  'post_modified_gmt' => '2017-08-21 11:31:41',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1863',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'lifestyle',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1865,
  'post_date' => '2008-06-26 02:49:39',
  'post_date_gmt' => '2008-06-26 02:49:39',
  'post_content' => 'Vivamus pharetra magna fermentum tincidunt imperdiet. Aenean venenatis sollicitudin odio in ultrices. Proin a nibh at dolor rhoncus pulvinar. Nullam eget tincidunt enim.',
  'post_title' => 'Clean Air',
  'post_excerpt' => '',
  'post_name' => 'clean-air',
  'post_modified' => '2017-08-21 11:31:39',
  'post_modified_gmt' => '2017-08-21 11:31:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1865',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'lifestyle',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2161,
  'post_date' => '2013-07-16 18:51:39',
  'post_date_gmt' => '2013-07-16 18:51:39',
  'post_content' => 'Maecenas cursus urna vitae tellus egestas venenatis. Quisque hendrerit massa sit amet erat bibendum fringilla. Aenean quis arcu porta, consectetur mauris ut, mollis dui. Donec pharetra a quam vitae adipiscing.',
  'post_title' => 'Tandem',
  'post_excerpt' => '',
  'post_name' => 'tandem',
  'post_modified' => '2017-08-21 11:31:30',
  'post_modified_gmt' => '2017-08-21 11:31:30',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2161',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2164,
  'post_date' => '2013-07-16 18:53:03',
  'post_date_gmt' => '2013-07-16 18:53:03',
  'post_content' => 'Donec tincidunt et massa sit amet sodales. In cursus augue ac sem ornare, eu interdum odio volutpat. Donec odio quam, lacinia quis nibh at, bibendum fringilla ante.',
  'post_title' => 'Needed Vacation',
  'post_excerpt' => '',
  'post_name' => 'needed-vacation',
  'post_modified' => '2017-08-21 11:31:29',
  'post_modified_gmt' => '2017-08-21 11:31:29',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2164',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2167,
  'post_date' => '2013-07-16 18:59:11',
  'post_date_gmt' => '2013-07-16 18:59:11',
  'post_content' => 'Donec id lectus sed risus fermentum auctor. In fringilla nulla tincidunt congue vulputate. Donec auctor risus ut elit pretium, ultrices iaculis velit interdum.',
  'post_title' => 'Vegetable Fun',
  'post_excerpt' => '',
  'post_name' => 'vegetable-fun',
  'post_modified' => '2017-08-21 11:31:26',
  'post_modified_gmt' => '2017-08-21 11:31:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2167',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2178,
  'post_date' => '2013-07-16 22:05:22',
  'post_date_gmt' => '2013-07-16 22:05:22',
  'post_content' => 'Pellentesque ipsum nisi, rhoncus dictum magna at, adipiscing commodo magna. Aenean accumsan erat a lacus semper, nec vulputate magna euismod. Maecenas a lacus rhoncus, ullamcorper sem consectetur, mollis lacus.',
  'post_title' => 'The Canyon',
  'post_excerpt' => '',
  'post_name' => 'the-canyon',
  'post_modified' => '2017-08-21 11:31:24',
  'post_modified_gmt' => '2017-08-21 11:31:24',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2178',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2376,
  'post_date' => '2014-10-02 22:34:25',
  'post_date_gmt' => '2014-10-02 22:34:25',
  'post_content' => '',
  'post_title' => 'Single Page',
  'post_excerpt' => '',
  'post_name' => 'single-page',
  'post_modified' => '2017-08-21 11:33:00',
  'post_modified_gmt' => '2017-08-21 11:33:00',
  'post_content_filtered' => '',
  'post_parent' => 2369,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2376',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'custom_menu' => 'single-page-menu',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Portfolio</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Showcase your work with Portfolio custom post type. You can display either image slider or a single featured image.</h3><p>[portfolio category=\\\\\\\\\\\\\\"featured\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"grid4\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"9eff36_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"6e8159_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"portfolio\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Highlight</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Attract viewer attention by showing animated circle Highlight posts (great for highlighting services or product features).</h3><p>[highlight category=\\\\\\\\\\\\\\"services\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"grid4\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"70\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"70\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"d4f2ff_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"586c75_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"highlight\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Team</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Show off your team member skills with animated color bars</h3><p>[team style=\\\\\\\\\\\\\\"list-post\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"6689d3_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"d2e0ff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"fff6d1_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"team\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Testimonial</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Customer Testimonials can be displayed in various layouts: slider, grid, and list post style.</h3><p>[testimonial style=\\\\\\\\\\\\\\"slider\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"a357e6_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ecc7ff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"fffea5_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"testimonial-post-type\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Blog</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Seven blog layout options are available from list post style to various grid layouts</h3><p>[list_posts limit=\\\\\\\\\\\\\\"3\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"list-post circle-image\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" display=\\\\\\\\\\\\\\"excerpt\\\\\\\\\\\\\\" post_date=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"aec1e3_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"717a89_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"blog-3\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2381,
  'post_date' => '2014-10-02 22:35:38',
  'post_date_gmt' => '2014-10-02 22:35:38',
  'post_content' => '',
  'post_title' => 'Personal Demo Page',
  'post_excerpt' => '',
  'post_name' => 'personal',
  'post_modified' => '2017-08-21 11:32:58',
  'post_modified_gmt' => '2017-08-21 11:32:58',
  'post_content_filtered' => '',
  'post_parent' => 2369,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2381',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Hello!</h2>\\",\\"font_family\\":\\"Concert One\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align\\":\\"center\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"ffe1ee_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat/files/2013/07/90307403.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"500\\",\\"height_image\\":\\"500\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Nullam suscipit, est in tincidunt tempus, elit dui venenatis ligula, ut viverra orci ipsum quis dui. Fusce eros enim, dapibus nec malesuada eget, condimentum vitae eros. Fusce nec dolor et arcu ultricies ultrices sit amet at ipsum. Donec dictum tempus erat id pretium. Vestibulum vestibulum risus non sem posuere pellentesque.</p><p>[progress_bar label=\\\\\\\\\\\'Design\\\\\\\\\\\' color=\\\\\\\\\\\'#c594da\\\\\\\\\\\' percentage=\\\\\\\\\\\'80\\\\\\\\\\\']<br />[progress_bar label=\\\\\\\\\\\'Marketing\\\\\\\\\\\' color=\\\\\\\\\\\'#22d9e5\\\\\\\\\\\' percentage=\\\\\\\\\\\'60\\\\\\\\\\\']<br />[progress_bar label=\\\\\\\\\\\'Photograph\\\\\\\\\\\' color=\\\\\\\\\\\'#c594da\\\\\\\\\\\' percentage=\\\\\\\\\\\'75\\\\\\\\\\\']<br />[progress_bar label=\\\\\\\\\\\'Illustration\\\\\\\\\\\' color=\\\\\\\\\\\'#22d9e5\\\\\\\\\\\' percentage=\\\\\\\\\\\'70\\\\\\\\\\\']</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"ffe1ee_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>My Work</h2>\\",\\"font_family\\":\\"Concert One\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Aliquam congue molestie leo. Proin eget nibh vitae lectus luctus commodo. Cras ut quam lacus. Integer euismod rhoncus purus ut vehicula.</h3><p>[portfolio category=\\\\\\\\\\\'featured\\\\\\\\\\\' style=\\\\\\\\\\\\\\"grid4\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"ffad33_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Testimonials</h2>\\",\\"font_family\\":\\"Concert One\\",\\"font_color\\":\\"666666_1.00\\",\\"text_align\\":\\"center\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[testimonial style=\\\\\\\\\\\\\\"slider\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"F7F2DD_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"666666_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Contact</h2>\\",\\"font_family\\":\\"Concert One\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"https://themify.me/demo/themes/flat/files/2013/07/green.gif\\",\\"background_repeat\\":\\"repeat\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"33d6d6_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[contact-form-7 id=\\\\\\\\\\\\\\"138\\\\\\\\\\\\\\" title=\\\\\\\\\\\\\\"Contact\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"mod_settings\\":{\\"mod_title_map\\":\\"Map\\",\\"address_map\\":\\"Yonge Street and Eglinton Ave. \\\\nToronto, Ontario, Canada\\",\\"zoom_map\\":\\"12\\",\\"w_map\\":\\"100\\",\\"unit_w\\":\\"%\\",\\"h_map\\":\\"300\\",\\"unit_h\\":\\"px\\",\\"b_style_map\\":\\"solid\\",\\"b_width_map\\":\\"1\\",\\"b_color_map\\":\\"030303\\",\\"type_map\\":\\"ROADMAP\\",\\"scrollwheel_map\\":\\"enable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean quis nibh odio. Proin et ipsum quam. Curabitur vitae viverra urna. Sed blandit tristique nunc, ac dapibus metus iaculis in.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"https://themify.me/demo/themes/flat/files/2013/07/green.gif\\",\\"background_repeat\\":\\"repeat\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"33d6d6_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2205,
  'post_date' => '2013-10-11 18:49:29',
  'post_date_gmt' => '2013-10-11 18:49:29',
  'post_content' => '',
  'post_title' => 'Blog - 3 Columns',
  'post_excerpt' => '',
  'post_name' => 'blog-3-columns',
  'post_modified' => '2017-08-21 11:33:10',
  'post_modified_gmt' => '2017-08-21 11:33:10',
  'post_content_filtered' => '',
  'post_parent' => 2156,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2205',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid3',
    'posts_per_page' => '6',
    'display_content' => 'excerpt',
    'image_width' => '328',
    'image_height' => '230',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2369,
  'post_date' => '2014-10-02 22:30:53',
  'post_date_gmt' => '2014-10-02 22:30:53',
  'post_content' => '<!--themify_builder_static--><h2 style="text-align: center;">Discover the new<br />Flat Theme</h2>
 <p>Flat is a beautiful, modern, bold typographic, colorful theme coded with HTML5 and CSS3. Impress your visitors with cool animation effects: fade-in, fly-in, slide-in, animated color bars and circles.</p><a href="https://themify.me/demo/themes/flat/features/">View Features</a> <a href="https://themify.me/themes/flat">Get Flat Theme</a>
 <h2 style="text-align: center;">Features</h2>
 
 <img src="https://themify.me/demo/themes/flat/files/2013/07/129057911-300x300.jpg" width="300" height="300" title="Themify Builder" alt="With Themify Builder packed in Flat theme, you can build any content layout using the frontend drag " srcset="https://themify.me/demo/themes/flat/files/2013/07/129057911-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/129057911-150x150.jpg 150w" sizes="(max-width: 300px) 100vw, 300px" /> <h3> Themify Builder </h3> <h4>With Themify Builder packed in Flat theme, you can build any content layout using the frontend drag &#038; drop interface. What you see on the page is what you get, don&#8217;t need to switch back and front. This section block is created with the Builder.</h4> 
 
 <img src="https://themify.me/demo/themes/flat/files/2013/07/112533923-300x300.jpg" width="300" height="300" title="Modern Technology " alt="Static designs are boring. Modern web design is about interaction and technology. Flat theme utilized HTML5, Javascript, and CSS3 to &#039;pretty-ize&#039; the design. Content blocks are presented beautifully with fade-in, slide-in, drop-in, animated circles and progress bars. Browse around this demo site to see them." srcset="https://themify.me/demo/themes/flat/files/2013/07/112533923-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/112533923-150x150.jpg 150w" sizes="(max-width: 300px) 100vw, 300px" /> <h3> Modern Technology & Design </h3> <h4>Static designs are boring. Modern web design is about interaction and technology. Flat theme utilized HTML5, Javascript, and CSS3 to &#8216;pretty-ize&#8217; the design. Content blocks are presented beautifully with fade-in, slide-in, drop-in, animated circles and progress bars. Browse around this demo site to see them.</h4> 
 
 <img src="https://themify.me/demo/themes/flat/files/2013/07/57935701-300x300.jpg" width="300" height="300" title="Fully Customizable" alt="Themify is known to make customizable themes. Themify&#039;s backend option panel gives you complete styling options. You can customize the font, background, image, and color. No coding required. Just click and select." srcset="https://themify.me/demo/themes/flat/files/2013/07/57935701-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/57935701-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/57935701.jpg 1000w" sizes="(max-width: 300px) 100vw, 300px" /> <h3> Fully Customizable </h3> <h4>Themify is known to make customizable themes. Themify&#8217;s backend option panel gives you complete styling options. You can customize the font, background, image, and color. No coding required. Just click and select.</h4> 
 <h2 style="text-align: center;">Services</h2>
 <article id="highlight-42"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-tv-100x100.png" width="100" height="100" alt="icon tv" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-tv.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-80x80.png 80w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-68x68.png 68w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-978x978.png 978w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-144x144.png 144w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>Web Design</h1> 
 <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor.</p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=42&#038;action=edit">Edit</a>] 
 </article>
<article id="highlight-40"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-tool-100x100.png" width="100" height="100" alt="icon tool" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-tool.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-80x80.png 80w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-68x68.png 68w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-978x978.png 978w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-144x144.png 144w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>Development</h1> 
 <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.</p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=40&#038;action=edit">Edit</a>] 
 </article>
<article id="highlight-38"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-100x100.png" width="100" height="100" alt="icon shopping cart" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-80x80.png 80w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-68x68.png 68w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-978x978.png 978w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-144x144.png 144w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>E-commerce</h1> 
 <p>Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.</p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=38&#038;action=edit">Edit</a>] 
 </article>
<article id="highlight-36"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart-100x100.png" width="100" height="100" alt="icon stock chart" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart-978x978.png 978w, https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart-144x144.png 144w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>Advertising</h1> 
 <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.</p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=36&#038;action=edit">Edit</a>] 
 </article>
 <h2 style="text-align: center;">Our Team</h2>
 <article id="team-48"> 
 <figure> <a href="https://themify.me/demo/themes/flat/team/amy-weaver/" title="Amy Weaver"> <img src="https://themify.me/demo/themes/flat/files/2013/07/86527867-144x144.jpg" width="144" height="144" alt="86527867" srcset="https://themify.me/demo/themes/flat/files/2013/07/86527867-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/86527867-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/86527867-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/86527867-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/86527867.jpg 667w" sizes="(max-width: 144px) 100vw, 144px" /> </a> </figure> 
 <h1> <a href="https://themify.me/demo/themes/flat/team/amy-weaver/" title="Amy Weaver"> Amy Weaver </a> Project Manager </h1> 
 <p>Maecenas luctus aliquet risus ac feugiat. Curabitur enim mi, placerat sit amet porttitor ac, mollis lobortis elit. Cras sit amet erat eget dolor varius tristique. Duis eu nisl tortor. Mauris pulvinar metus eget nulla adipiscing consectetur.</p> 
 <p> <a href="http://twitter.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png" alt="social-link" /></a>
<a href="http://facebook.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png" alt="social-link" /></a>
<a href="http://pinterest.com/"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png" alt="social-link" /></a> </p> 
 
 <i>Project Management</i>
 <i>Marketing</i>
 <i>Logistics</i> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=48&#038;action=edit">Edit Team</a>] </article>
<article id="team-45"> 
 <figure> <a href="https://themify.me/demo/themes/flat/team/jacqueline-willis/" title="Jacqueline Willis"> <img src="https://themify.me/demo/themes/flat/files/2013/07/84008631-144x144.jpg" width="144" height="144" alt="84008631" srcset="https://themify.me/demo/themes/flat/files/2013/07/84008631-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/84008631-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/84008631-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/84008631-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/84008631.jpg 548w" sizes="(max-width: 144px) 100vw, 144px" /> </a> </figure> 
 <h1> <a href="https://themify.me/demo/themes/flat/team/jacqueline-willis/" title="Jacqueline Willis"> Jacqueline Willis </a> Web Designer </h1> 
 <p>Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. dolor quis sollicitudin accumsan, elit turpis tempor est mattis.</p> 
 <p> <a href="http://twitter.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png" alt="social-link" /></a>
<a href="http://facebook.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png" alt="social-link" /></a>
<a href="http://pinterest.com/"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png" alt="social-link" /></a> </p> 
 
 <i>Graphic Design</i>
 <i>Web Design</i>
 <i>jQuery</i> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=45&#038;action=edit">Edit Team</a>] </article>
 <h2 style="text-align: center;">Our History</h2>
 <ul> <li id="timeline-51"> <h3> Jul 2008 </h3> 
 &bull; 
 
 
 
 <p>Company is founded</p> 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=51&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-52"> <h3> Aug 2008 </h3> 
 &bull; 
 
 
 <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/team-300x91.png" width="300" alt="team" srcset="https://themify.me/demo/themes/flat/files/2013/07/team-300x91.png 300w, https://themify.me/demo/themes/flat/files/2013/07/team.png 588w" sizes="(max-width: 300px) 100vw, 300px" /> </figure> 
 <p>3 more people joined our team</p> 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=52&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-54"> <h3> Oct 2009 </h3> 
 &bull; 
 
 
 <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/109134812-400x266.jpg" width="400" alt="109134812" srcset="https://themify.me/demo/themes/flat/files/2013/07/109134812-400x266.jpg 400w, https://themify.me/demo/themes/flat/files/2013/07/109134812-300x200.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/109134812.jpg 1000w" sizes="(max-width: 400px) 100vw, 400px" /> </figure> 
 <p>We moved in the first office space</p> 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=54&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-56"> <h3> Oct 2010 </h3> 
 &bull; 
 
 
 <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/83253659-550x365.jpg" width="550" alt="83253659" srcset="https://themify.me/demo/themes/flat/files/2013/07/83253659-550x365.jpg 550w, https://themify.me/demo/themes/flat/files/2013/07/83253659-300x199.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/83253659.jpg 1000w" sizes="(max-width: 550px) 100vw, 550px" /> </figure> 
 <p>Corporate function party</p> 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=56&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-59"> <h3> Jul 2013 </h3> 
 &bull; 
 
 
 
 <p><a href="http://www.youtube.com/watch?v=hHw6VKKjcpQ"><img src="https://themify.me/demo/themes/flat/files/2013/07/play.png" alt="play" width="100" height="100" /></a><br /> Office builder construction begins!</p> 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=59&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
</ul>
 <h2 style="text-align: center;">Featured Work</h2>
 
<article id="portfolio-157"> <ul data-id="portfolio-slider-1571" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/dark-gallery/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/26100514-221x221.jpg" width="221" height="221" alt="26100514" srcset="https://themify.me/demo/themes/flat/files/2013/07/26100514-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/26100514-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/26100514-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/26100514-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/26100514-670x670.jpg 670w, https://themify.me/demo/themes/flat/files/2013/07/26100514-978x978.jpg 978w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/dark-gallery/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/70502623-221x221.jpg" width="221" height="221" alt="70502623" srcset="https://themify.me/demo/themes/flat/files/2013/07/70502623-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/70502623-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/70502623-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/70502623-240x240.jpg 240w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/dark-gallery/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/74418763-221x221.jpg" width="221" height="221" alt="74418763" srcset="https://themify.me/demo/themes/flat/files/2013/07/74418763-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/74418763-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/74418763-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/74418763-240x240.jpg 240w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/dark-gallery/">Dark Gallery</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=157&#038;action=edit">Edit</a>] </article>
<article id="portfolio-65"> <ul data-id="portfolio-slider-651" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/watercolor/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-221x221.jpg" width="221" height="221" alt="shutterstock_110864450" srcset="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/watercolor/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-221x221.jpg" width="221" height="221" alt="shutterstock_59513041" srcset="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/watercolor/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-221x221.jpg" width="221" height="221" alt="shutterstock_59623786" srcset="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-978x978.jpg 978w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/watercolor/">Watercolor</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=65&#038;action=edit">Edit</a>] </article>
<article id="portfolio-63"> <ul data-id="portfolio-slider-631" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/red-rose/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/639828071-221x221.jpg" width="221" height="221" alt="63982807" srcset="https://themify.me/demo/themes/flat/files/2013/07/639828071-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/639828071-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/639828071-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/639828071-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/red-rose/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/63637366-221x221.jpg" width="221" height="221" alt="63637366" srcset="https://themify.me/demo/themes/flat/files/2013/07/63637366-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/63637366-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/63637366-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/63637366-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/63637366-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/63637366-242x242.jpg 242w, https://themify.me/demo/themes/flat/files/2013/07/63637366-518x518.jpg 518w, https://themify.me/demo/themes/flat/files/2013/07/63637366-335x335.jpg 335w, https://themify.me/demo/themes/flat/files/2013/07/63637366.jpg 1000w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/red-rose/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/68392120-221x221.jpg" width="221" height="221" alt="68392120" srcset="https://themify.me/demo/themes/flat/files/2013/07/68392120-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/68392120-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/68392120-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/68392120-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/red-rose/">Red Rose</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=63&#038;action=edit">Edit</a>] </article>
<article id="portfolio-151"> <ul data-id="portfolio-slider-1511" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/black-white/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/89686039-221x221.jpg" width="221" height="221" alt="89686039" srcset="https://themify.me/demo/themes/flat/files/2013/07/89686039-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/89686039-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/89686039-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/89686039-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/89686039-670x670.jpg 670w, https://themify.me/demo/themes/flat/files/2013/07/89686039-978x978.jpg 978w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/black-white/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/97479520-221x221.jpg" width="221" height="221" alt="97479520" srcset="https://themify.me/demo/themes/flat/files/2013/07/97479520-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/97479520-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/97479520-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/97479520-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/black-white/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/dv1483002-221x221.jpg" width="221" height="221" alt="dv1483002" srcset="https://themify.me/demo/themes/flat/files/2013/07/dv1483002-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/dv1483002-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/dv1483002-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/dv1483002-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/black-white/">Black &#038; White</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=151&#038;action=edit">Edit</a>] </article>
 <h2 style="text-align: center;">Blog</h2>
 
<article id="post-2178"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/the-canyon/"><img src="https://themify.me/demo/themes/flat/files/2013/07/136056098-145x145.jpg" width="145" height="145" alt="136056098" srcset="https://themify.me/demo/themes/flat/files/2013/07/136056098-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/136056098-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/136056098-100x100.jpg 100w, https://themify.me/demo/themes/flat/files/2013/07/136056098-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/136056098-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/136056098-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/136056098-670x670.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/the-canyon/">The Canyon</a> </h2> <p> <time datetime="2013-07-16">July 16, 2013</time> </p> 
 <p>Pellentesque ipsum nisi, rhoncus dictum magna at, adipiscing commodo magna. Aenean accumsan erat a lacus semper, nec vulputate magna euismod. Maecenas a lacus rhoncus, ullamcorper sem consectetur, mollis lacus.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2178&#038;action=edit">Edit</a>] </article>
<article id="post-2167"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/vegetable-fun/"><img src="https://themify.me/demo/themes/flat/files/2013/07/132261116-145x145.jpg" width="145" height="145" alt="132261116" srcset="https://themify.me/demo/themes/flat/files/2013/07/132261116-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/132261116-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/132261116-100x100.jpg 100w, https://themify.me/demo/themes/flat/files/2013/07/132261116-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/132261116-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/132261116-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/132261116-670x667.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/vegetable-fun/">Vegetable Fun</a> </h2> <p> <time datetime="2013-07-16">July 16, 2013</time> </p> 
 <p>Donec id lectus sed risus fermentum auctor. In fringilla nulla tincidunt congue vulputate. Donec auctor risus ut elit pretium, ultrices iaculis velit interdum.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2167&#038;action=edit">Edit</a>] </article>
<article id="post-2164"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/needed-vacation/"><img src="https://themify.me/demo/themes/flat/files/2013/07/128686832-145x145.jpg" width="145" height="145" alt="128686832" srcset="https://themify.me/demo/themes/flat/files/2013/07/128686832-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/128686832-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/128686832-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/128686832-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/128686832-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/128686832-670x666.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/needed-vacation/">Needed Vacation</a> </h2> <p> <time datetime="2013-07-16">July 16, 2013</time> </p> 
 <p>Donec tincidunt et massa sit amet sodales. In cursus augue ac sem ornare, eu interdum odio volutpat. Donec odio quam, lacinia quis nibh at, bibendum fringilla ante.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2164&#038;action=edit">Edit</a>] </article>
 <h2 style="text-align: center;">What Are People Saying</h2>
 <ul data-id="testimonial-slider-1" data-autoplay="4000" data-effect="slide" data-speed="500"> <li>
<article id="testimonial-22"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/82152160-144x144.jpg" width="144" height="144" alt="82152160" srcset="https://themify.me/demo/themes/flat/files/2013/07/82152160-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/82152160-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/82152160-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/82152160-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/82152160-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/82152160.jpg 369w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Diana Jones</h1> <p>Maecenas in orci nunc. Curabitur velit sapien, mollis vel aliquam et, dignissim consequat eros. Curabitur egestas quam dapibus arcu egestas mollis.</p> 
 <p> Diana Jones &ndash; CEO, Nice Company </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=22&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-20"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/112268515-144x144.jpg" width="144" height="144" alt="112268515" srcset="https://themify.me/demo/themes/flat/files/2013/07/112268515-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/112268515-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/112268515-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/112268515-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/112268515-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/112268515.jpg 577w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Amanda Elric</h1> <p>Rravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop’s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.</p> 
 <p> Amanda Elric &ndash; Manager, Themify </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=20&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-12"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/124661612-144x144.jpg" width="144" height="144" alt="124661612" srcset="https://themify.me/demo/themes/flat/files/2013/07/124661612-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/124661612-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/124661612-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/124661612-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/124661612.jpg 373w, https://themify.me/demo/themes/flat/files/2013/07/124661612-978x978.jpg 978w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Mike Canlas</h1> <p>Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop&#8217;s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.</p> 
 <p> Mike Canlas &ndash; Owner </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=12&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-1592"> <figure> <img src="https://themify.me/demo/themes/flat/files/2012/11/105942619-144x144.jpg" width="144" height="144" alt="105942619" srcset="https://themify.me/demo/themes/flat/files/2012/11/105942619-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2012/11/105942619-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2012/11/105942619-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2012/11/105942619-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2012/11/105942619-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2012/11/105942619.jpg 306w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Exceeded Our Expectation</h1> <p>Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla. Fusce ut sem est. In eu sagittis felis. In gravida arcu ut neque ornare vitae rutrum tu. Cras a fringilla nunc. Suspendisse volutpat, eros cong rpis vehicula.</p> 
 <p> Vanissa &ndash; Manager </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=1592&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li> </ul>
 <h2 style="text-align: center;">CALL TO ACTION ROW!</h2>
 <h3 style="text-align: center;">Liking what you see here?</h3><p style="text-align: center;"><a href="https://themify.me/themes/flat">Get Flat Now!</a><!--/themify_builder_static-->',
  'post_title' => 'Home',
  'post_excerpt' => '',
  'post_name' => 'home',
  'post_modified' => '2018-03-06 23:48:51',
  'post_modified_gmt' => '2018-03-06 23:48:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2369',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Discover the new<br \\\\/>Flat Theme<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Flat is a beautiful, modern, bold typographic, colorful theme coded with HTML5 and CSS3. Impress your visitors with cool animation effects: fade-in, fly-in, slide-in, animated color bars and circles.<\\\\/p><p>[button style=\\\\\\\\\\\\\\"large rounded red flat\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/flat\\\\/features\\\\/\\\\\\\\\\\\\\"]View Features[\\\\/button] [button style=\\\\\\\\\\\\\\"large rounded green flat\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/flat\\\\\\\\\\\\\\"]Get Flat Theme[\\\\/button]<\\\\/p>\\"}}]}],\\"styling\\":{\\"animation_effect\\":\\"fadeInUp\\",\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Features<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat\\\\/files\\\\/2013\\\\/07\\\\/129057911.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"300\\",\\"title_image\\":\\"Themify Builder\\",\\"caption_image\\":\\"<h4>With Themify Builder packed in Flat theme, you can build any content layout using the frontend drag & drop interface. What you see on the page is what you get, don\\\\\\\\\\\'t need to switch back and front. This section block is created with the Builder.<\\\\/h4>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat\\\\/files\\\\/2013\\\\/07\\\\/112533923.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"300\\",\\"title_image\\":\\"Modern Technology & Design\\",\\"caption_image\\":\\"<h4>Static designs are boring. Modern web design is about interaction and technology. Flat theme utilized HTML5, Javascript, and CSS3 to \\\\\\\\\\\'pretty-ize\\\\\\\\\\\' the design. Content blocks are presented beautifully with fade-in, slide-in, drop-in, animated circles and progress bars. Browse around this demo site to see them.<\\\\/h4>\\",\\"animation_effect\\":\\"fadeInRight\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat\\\\/files\\\\/2013\\\\/07\\\\/57935701.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"300\\",\\"title_image\\":\\"Fully Customizable\\",\\"caption_image\\":\\"<h4>Themify is known to make customizable themes. Themify\\\\\\\\\\\'s backend option panel gives you complete styling options. You can customize the font, background, image, and color. No coding required. Just click and select.<\\\\/h4>\\",\\"animation_effect\\":\\"fadeInLeft\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Services<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[highlight limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"grid4\\\\\\\\\\\\\\" category=\\\\\\\\\\\\\\"services\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"100\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"100\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our Team<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[team style=\\\\\\\\\\\\\\"list-post\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our History<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[timeline category=\\\\\\\\\\\\\\"company-timeline\\\\\\\\\\\\\\" order=\\\\\\\\\\\\\\"ASC\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"10\\\\\\\\\\\\\\" use_original_dimensions=\\\\\\\\\\\\\\"yes\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Featured Work<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[portfolio category=\\\\\\\\\\\'featured\\\\\\\\\\\' style=\\\\\\\\\\\'grid4\\\\\\\\\\\']<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Blog<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[list_posts limit=\\\\\\\\\\\\\\"3\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"list-post circle-image\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" display=\\\\\\\\\\\\\\"excerpt\\\\\\\\\\\\\\" post_date=\\\\\\\\\\\\\\"yes\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">What Are People Saying<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[testimonial style=\\\\\\\\\\\\\\"slider\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">CALL TO ACTION ROW!<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Liking what you see here?<\\\\/h3><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">[button style=\\\\\\\\\\\\\\"large rounded flat black\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/flat\\\\\\\\\\\\\\"]Get Flat Now![\\\\/button]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"f06544_1.00\\",\\"font_color\\":\\"ffdbba_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2371,
  'post_date' => '2014-10-02 22:31:56',
  'post_date_gmt' => '2014-10-02 22:31:56',
  'post_content' => '<!--themify_builder_static--><h2 style="text-align: center;">Discover the new<br />Flat Theme</h2>
 <h3>Flat is a beautiful, modern, bold typographic, colorful theme coded with HTML5 and CSS3. Impress your visitors with cool animation effects: fade-in, fly-in, slide-in, animated color bars and circles.</h3><a href="https://themify.me/demo/themes/flat/features/">View Features</a> <a href="https://themify.me/themes/flat">Get Flat Theme</a>
 <h2 style="text-align: center;">Features</h2>
 
 <img src="https://themify.me/demo/themes/flat/files/2013/07/129057911-300x300.jpg" width="300" height="300" title="Themify Builder" alt="With Themify Builder packed in Flat theme, you can build any content layout using the frontend drag " srcset="https://themify.me/demo/themes/flat/files/2013/07/129057911-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/129057911-150x150.jpg 150w" sizes="(max-width: 300px) 100vw, 300px" /> <h3> Themify Builder </h3> <h4>With Themify Builder packed in Flat theme, you can build any content layout using the frontend drag &#038; drop interface. What you see on the page is what you get, don&#8217;t need to switch back and front. This section block is created with the Builder.</h4> 
 
 <img src="https://themify.me/demo/themes/flat/files/2013/07/112533923-300x300.jpg" width="300" height="300" title="Modern Technology " alt="Static designs are boring. Modern web design is about interaction and technology. Flat theme utilized HTML5, Javascript, and CSS3 to &#039;pretty-ize&#039; the design. Content blocks are presented beautifully with fade-in, slide-in, drop-in, animated circles and progress bars. Browse around this demo site to see them." srcset="https://themify.me/demo/themes/flat/files/2013/07/112533923-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/112533923-150x150.jpg 150w" sizes="(max-width: 300px) 100vw, 300px" /> <h3> Modern Technology & Design </h3> <h4>Static designs are boring. Modern web design is about interaction and technology. Flat theme utilized HTML5, Javascript, and CSS3 to &#8216;pretty-ize&#8217; the design. Content blocks are presented beautifully with fade-in, slide-in, drop-in, animated circles and progress bars. Browse around this demo site to see them.</h4> 
 
 <img src="https://themify.me/demo/themes/flat/files/2013/07/57935701-300x300.jpg" width="300" height="300" title="Fully Customizable" alt="Themify is known to make customizable themes. Themify&#039;s backend option panel gives you complete styling options. You can customize the font, background, image, and color. No coding required. Just click and select." srcset="https://themify.me/demo/themes/flat/files/2013/07/57935701-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/57935701-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/57935701.jpg 1000w" sizes="(max-width: 300px) 100vw, 300px" /> <h3> Fully Customizable </h3> <h4>Themify is known to make customizable themes. Themify&#8217;s backend option panel gives you complete styling options. You can customize the font, background, image, and color. No coding required. Just click and select.</h4> 
 <h2 style="text-align: center;">Services</h2>
 <p style="text-align: center;"> <article id="highlight-42"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-tv-100x100.png" width="100" height="100" alt="icon tv" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-tv.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-80x80.png 80w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-68x68.png 68w, https://themify.me/demo/themes/flat/files/2013/07/icon-tv-978x978.png 978w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>Web Design</h1> 
 <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor.</p>
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=42&#038;action=edit">Edit</a>] 
 </article>
<article id="highlight-40"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-tool-100x100.png" width="100" height="100" alt="icon tool" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-tool.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-80x80.png 80w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-68x68.png 68w, https://themify.me/demo/themes/flat/files/2013/07/icon-tool-978x978.png 978w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>Development</h1> 
 <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.</p>
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=40&#038;action=edit">Edit</a>] 
 </article>
<article id="highlight-38"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-100x100.png" width="100" height="100" alt="icon shopping cart" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-80x80.png 80w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-68x68.png 68w, https://themify.me/demo/themes/flat/files/2013/07/icon-shopping-cart-978x978.png 978w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>E-commerce</h1> 
 <p>Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.</p>
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=38&#038;action=edit">Edit</a>] 
 </article>
<article id="highlight-36"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart-100x100.png" width="100" height="100" alt="icon stock chart" srcset="https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart.png 100w, https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart-70x70.png 70w, https://themify.me/demo/themes/flat/files/2013/07/icon-stock-chart-978x978.png 978w" sizes="(max-width: 100px) 100vw, 100px" /> </figure> <h1>Advertising</h1> 
 <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.</p>
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=36&#038;action=edit">Edit</a>] 
 </article>
</p>
 <h2 style="text-align: center;">Our Team</h2>
 <article id="team-48"> 
 <figure> <a href="https://themify.me/demo/themes/flat/team/amy-weaver/" title="Amy Weaver"> <img src="https://themify.me/demo/themes/flat/files/2013/07/86527867-144x144.jpg" width="144" height="144" alt="86527867" srcset="https://themify.me/demo/themes/flat/files/2013/07/86527867-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/86527867-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/86527867-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/86527867-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/86527867.jpg 667w" sizes="(max-width: 144px) 100vw, 144px" /> </a> </figure> 
 <h1> <a href="https://themify.me/demo/themes/flat/team/amy-weaver/" title="Amy Weaver"> Amy Weaver </a> Project Manager </h1> 
 <p>Maecenas luctus aliquet risus ac feugiat. Curabitur enim mi, placerat sit amet porttitor ac, mollis lobortis elit. Cras sit amet erat eget dolor varius tristique. Duis eu nisl tortor. Mauris pulvinar metus eget nulla adipiscing consectetur.</p>
 
 <p> <a href="http://twitter.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png" alt="social-link" /></a>
<a href="http://facebook.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png" alt="social-link" /></a>
<a href="http://pinterest.com/"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png" alt="social-link" /></a> </p> 
 
 <i>Project Management</i>
 <i>Marketing</i>
 <i>Logistics</i> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=48&#038;action=edit">Edit Team</a>] </article>
<article id="team-45"> 
 <figure> <a href="https://themify.me/demo/themes/flat/team/jacqueline-willis/" title="Jacqueline Willis"> <img src="https://themify.me/demo/themes/flat/files/2013/07/84008631-144x144.jpg" width="144" height="144" alt="84008631" srcset="https://themify.me/demo/themes/flat/files/2013/07/84008631-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/84008631-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/84008631-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/84008631-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/84008631.jpg 548w" sizes="(max-width: 144px) 100vw, 144px" /> </a> </figure> 
 <h1> <a href="https://themify.me/demo/themes/flat/team/jacqueline-willis/" title="Jacqueline Willis"> Jacqueline Willis </a> Web Designer </h1> 
 <p>Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. dolor quis sollicitudin accumsan, elit turpis tempor est mattis.</p>
 
 <p> <a href="http://twitter.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png" alt="social-link" /></a>
<a href="http://facebook.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png" alt="social-link" /></a>
<a href="http://pinterest.com/"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png" alt="social-link" /></a> </p> 
 
 <i>Graphic Design</i>
 <i>Web Design</i>
 <i>jQuery</i> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=45&#038;action=edit">Edit Team</a>] </article>
 <h2 style="text-align: center;">Our History</h2>
 <ul> <li id="timeline-51"> <h3> Jul 2008 </h3> 
 &bull; 
 
 
 
 <p>Company is founded</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=51&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-52"> <h3> Aug 2008 </h3> 
 &bull; 
 
 
 <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/team-300x91.png" width="300" alt="team" srcset="https://themify.me/demo/themes/flat/files/2013/07/team-300x91.png 300w, https://themify.me/demo/themes/flat/files/2013/07/team.png 588w" sizes="(max-width: 300px) 100vw, 300px" /> </figure> 
 <p>3 more people joined our team</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=52&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-54"> <h3> Oct 2009 </h3> 
 &bull; 
 
 
 <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/109134812-400x266.jpg" width="400" alt="109134812" srcset="https://themify.me/demo/themes/flat/files/2013/07/109134812-400x266.jpg 400w, https://themify.me/demo/themes/flat/files/2013/07/109134812-300x200.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/109134812.jpg 1000w" sizes="(max-width: 400px) 100vw, 400px" /> </figure> 
 <p>We moved in the first office space</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=54&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-56"> <h3> Oct 2010 </h3> 
 &bull; 
 
 
 <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/83253659-550x365.jpg" width="550" alt="83253659" srcset="https://themify.me/demo/themes/flat/files/2013/07/83253659-550x365.jpg 550w, https://themify.me/demo/themes/flat/files/2013/07/83253659-300x199.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/83253659.jpg 1000w" sizes="(max-width: 550px) 100vw, 550px" /> </figure> 
 <p>Corporate function party</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=56&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-59"> <h3> Jul 2013 </h3> 
 &bull; 
 
 
 
 <p><a href="http://www.youtube.com/watch?v=hHw6VKKjcpQ"><img src="https://themify.me/demo/themes/flat/files/2013/07/play.png" alt="play" width="100" height="100" /></a><br /> Office builder construction begins!</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=59&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
</ul>
 <h2 style="text-align: center;">Featured Work</h2>
 
 <h2 style="text-align: center;">Blog</h2>
 
<article id="post-2178"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/the-canyon/"><img src="https://themify.me/demo/themes/flat/files/2013/07/136056098-145x145.jpg" width="145" height="145" alt="136056098" srcset="https://themify.me/demo/themes/flat/files/2013/07/136056098-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/136056098-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/136056098-100x100.jpg 100w, https://themify.me/demo/themes/flat/files/2013/07/136056098-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/136056098-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/136056098-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/136056098-670x670.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/the-canyon/">The Canyon</a> </h2> <p> <time datetime="2013-07-16">July 16, 2013</time> </p> 
 <p>Pellentesque ipsum nisi, rhoncus dictum magna at, adipiscing commodo magna. Aenean accumsan erat a lacus semper, nec vulputate magna euismod. Maecenas a lacus rhoncus, ullamcorper sem consectetur, mollis lacus.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2178&#038;action=edit">Edit</a>] </article>
<article id="post-2167"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/vegetable-fun/"><img src="https://themify.me/demo/themes/flat/files/2013/07/132261116-145x145.jpg" width="145" height="145" alt="132261116" srcset="https://themify.me/demo/themes/flat/files/2013/07/132261116-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/132261116-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/132261116-100x100.jpg 100w, https://themify.me/demo/themes/flat/files/2013/07/132261116-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/132261116-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/132261116-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/132261116-670x667.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/vegetable-fun/">Vegetable Fun</a> </h2> <p> <time datetime="2013-07-16">July 16, 2013</time> </p> 
 <p>Donec id lectus sed risus fermentum auctor. In fringilla nulla tincidunt congue vulputate. Donec auctor risus ut elit pretium, ultrices iaculis velit interdum.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2167&#038;action=edit">Edit</a>] </article>
<article id="post-2164"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/needed-vacation/"><img src="https://themify.me/demo/themes/flat/files/2013/07/128686832-145x145.jpg" width="145" height="145" alt="128686832" srcset="https://themify.me/demo/themes/flat/files/2013/07/128686832-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/128686832-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/128686832-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/128686832-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/128686832-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/128686832-670x666.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/needed-vacation/">Needed Vacation</a> </h2> <p> <time datetime="2013-07-16">July 16, 2013</time> </p> 
 <p>Donec tincidunt et massa sit amet sodales. In cursus augue ac sem ornare, eu interdum odio volutpat. Donec odio quam, lacinia quis nibh at, bibendum fringilla ante.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2164&#038;action=edit">Edit</a>] </article>
 <h2 style="text-align: center;">What Are People Saying</h2>
 <ul data-id="testimonial-slider-1" data-autoplay="4000" data-effect="slide" data-speed="500"> <li>
<article id="testimonial-22"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/82152160-144x144.jpg" width="144" height="144" alt="82152160" srcset="https://themify.me/demo/themes/flat/files/2013/07/82152160-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/82152160-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/82152160-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/82152160-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/82152160-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/82152160.jpg 369w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Diana Jones</h1> <p>Maecenas in orci nunc. Curabitur velit sapien, mollis vel aliquam et, dignissim consequat eros. Curabitur egestas quam dapibus arcu egestas mollis.</p>
 
 <p> Diana Jones &ndash; CEO, Nice Company </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=22&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-20"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/112268515-144x144.jpg" width="144" height="144" alt="112268515" srcset="https://themify.me/demo/themes/flat/files/2013/07/112268515-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/112268515-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/112268515-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/112268515-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/112268515-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/112268515.jpg 577w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Amanda Elric</h1> <p>Rravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop’s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.</p>
 
 <p> Amanda Elric &ndash; Manager, Themify </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=20&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-12"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/124661612-144x144.jpg" width="144" height="144" alt="124661612" srcset="https://themify.me/demo/themes/flat/files/2013/07/124661612-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/124661612-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/124661612-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/124661612-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/124661612.jpg 373w, https://themify.me/demo/themes/flat/files/2013/07/124661612-978x978.jpg 978w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Mike Canlas</h1> <p>Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop&#8217;s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.</p>
 
 <p> Mike Canlas &ndash; Owner </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=12&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-1592"> <figure> <img src="https://themify.me/demo/themes/flat/files/2012/11/105942619-144x144.jpg" width="144" height="144" alt="105942619" srcset="https://themify.me/demo/themes/flat/files/2012/11/105942619-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2012/11/105942619-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2012/11/105942619-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2012/11/105942619-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2012/11/105942619-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2012/11/105942619.jpg 306w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Exceeded Our Expectation</h1> <p>Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla. Fusce ut sem est. In eu sagittis felis. In gravida arcu ut neque ornare vitae rutrum tu. Cras a fringilla nunc. Suspendisse volutpat, eros cong rpis vehicula.</p>
 
 <p> Vanissa &ndash; Manager </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=1592&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li> </ul>
 <h2 style="text-align: center;">Call To Action Row!</h2>
 <h3 style="text-align: center;">Liking what you see here?</h3><p style="text-align: center;"><a href="https://themify.me/themes/flat">Get Flat Now!</a><!--/themify_builder_static-->',
  'post_title' => 'Home - Color Version',
  'post_excerpt' => '',
  'post_name' => 'home-color',
  'post_modified' => '2017-10-27 19:39:03',
  'post_modified_gmt' => '2017-10-27 19:39:03',
  'post_content_filtered' => '',
  'post_parent' => 2369,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2371',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Discover the new<br \\\\/>Flat Theme<\\\\/h2>\\",\\"font_color\\":\\"030000_1.00\\",\\"cid\\":\\"c20\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Flat is a beautiful, modern, bold typographic, colorful theme coded with HTML5 and CSS3. Impress your visitors with cool animation effects: fade-in, fly-in, slide-in, animated color bars and circles.<\\\\/h3><p>[button style=\\\\\\\\\\\\\\"large rounded red flat\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/flat\\\\/features\\\\/\\\\\\\\\\\\\\"]View Features[\\\\/button] [button style=\\\\\\\\\\\\\\"large rounded green flat\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/flat\\\\\\\\\\\\\\"]Get Flat Theme[\\\\/button]<\\\\/p>\\",\\"cid\\":\\"c24\\"}}]}],\\"styling\\":{\\"animation_effect\\":\\"fadeInUp\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"efefe7_1.00\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Features<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c35\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat\\\\/files\\\\/2013\\\\/07\\\\/129057911.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"300\\",\\"title_image\\":\\"Themify Builder\\",\\"caption_image\\":\\"<h4>With Themify Builder packed in Flat theme, you can build any content layout using the frontend drag & drop interface. What you see on the page is what you get, don\\\\\\\\\\\'t need to switch back and front. This section block is created with the Builder.<\\\\/h4>\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"cid\\":\\"c39\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat\\\\/files\\\\/2013\\\\/07\\\\/112533923.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"300\\",\\"title_image\\":\\"Modern Technology & Design\\",\\"caption_image\\":\\"<h4>Static designs are boring. Modern web design is about interaction and technology. Flat theme utilized HTML5, Javascript, and CSS3 to \\\\\\\\\\\'pretty-ize\\\\\\\\\\\' the design. Content blocks are presented beautifully with fade-in, slide-in, drop-in, animated circles and progress bars. Browse around this demo site to see them.<\\\\/h4>\\",\\"animation_effect\\":\\"fadeInRight\\",\\"cid\\":\\"c43\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat\\\\/files\\\\/2013\\\\/07\\\\/57935701.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"300\\",\\"title_image\\":\\"Fully Customizable\\",\\"caption_image\\":\\"<h4>Themify is known to make customizable themes. Themify\\\\\\\\\\\'s backend option panel gives you complete styling options. You can customize the font, background, image, and color. No coding required. Just click and select.<\\\\/h4>\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"cid\\":\\"c47\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"c594da_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Services<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\",\\"cid\\":\\"c58\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">[highlight limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"grid4\\\\\\\\\\\\\\" category=\\\\\\\\\\\\\\"services\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"100\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"100\\\\\\\\\\\\\\"]<\\\\/p>\\",\\"cid\\":\\"c62\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"d4ebf1_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our Team<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c73\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[team style=\\\\\\\\\\\\\\"list-post\\\\\\\\\\\\\\"]<\\\\/p>\\",\\"cid\\":\\"c77\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"de8275_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our History<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c88\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[timeline category=\\\\\\\\\\\\\\"company-timeline\\\\\\\\\\\\\\" order=\\\\\\\\\\\\\\"ASC\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"10\\\\\\\\\\\\\\" use_original_dimensions=\\\\\\\\\\\\\\"yes\\\\\\\\\\\\\\"]<\\\\/p>\\",\\"cid\\":\\"c92\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"02daaf_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Featured Work<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c103\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[portfolio category=\\\\\\\\\\\'featured\\\\\\\\\\\' style=\\\\\\\\\\\'grid4\\\\\\\\\\\']<\\\\/p>\\",\\"cid\\":\\"c107\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"ff9933_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Blog<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c118\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[list_posts limit=\\\\\\\\\\\\\\"3\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"list-post circle-image\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" display=\\\\\\\\\\\\\\"excerpt\\\\\\\\\\\\\\" post_date=\\\\\\\\\\\\\\"yes\\\\\\\\\\\\\\"]<\\\\/p>\\",\\"cid\\":\\"c122\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"ffcc00_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">What Are People Saying<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c133\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[testimonial style=\\\\\\\\\\\\\\"slider\\\\\\\\\\\\\\"]<\\\\/p>\\",\\"cid\\":\\"c137\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"22d9e5_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Call To Action Row!<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c148\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Liking what you see here?<\\\\/h3><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">[button style=\\\\\\\\\\\\\\"large rounded flat black\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/flat\\\\\\\\\\\\\\"]Get Flat Now![\\\\/button]<\\\\/p>\\",\\"cid\\":\\"c152\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"f06544_1.00\\",\\"font_color\\":\\"ffdbba_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2367,
  'post_date' => '2014-10-02 22:39:13',
  'post_date_gmt' => '2014-10-02 22:39:13',
  'post_content' => '<!--themify_builder_static--><h2 style="text-align: center;">Theme Features</h2>
 <h3>This demo page highlights the main features of <a href="https://themify.me/themes/flat">Flat</a> theme.</h3><a href="https://themify.me/themes/flat">Get Flat Theme Now</a>
 <h2 style="text-align: center;">Builder Rows</h2>
 <h3>What you see on this page is constructed with Builder modules. The Builder modules comes with styling panels that allows you to customize the color, font, padding, margins, and background on each module. For this row we used a Text module in Heading 3, to display this text.</h3>
 <h2 style="text-align: center;">Themify Builder</h2>
 <h3>Themify Builder provides easy to use user interface which allows you to arrange the content blocks on the frontend by dragging and dropping. In other words, what you see is what you get. The content blocks can be built using various modules: Text, Slider, Video, Image, Post, Gallery, Tab, Accordion, Menu, etc.</h3><a href="https://themify.me/demo/themes/flat/builder-demos/">Builder Demos</a>
 
 <iframe width="1165" height="655" src="https://www.youtube.com/embed/hHw6VKKjcpQ?feature=oembed" allow="autoplay; encrypted-media" allowfullscreen></iframe> 
 
 <h2 style="text-align: center;">Portfolio</h2>
 <h3>Showcase your work with Portfolio custom post type. You can display either image slider or a single featured image.</h3>
<article id="portfolio-157"> <ul data-id="portfolio-slider-1571" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/dark-gallery/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/26100514-221x221.jpg" width="221" height="221" alt="26100514" srcset="https://themify.me/demo/themes/flat/files/2013/07/26100514-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/26100514-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/26100514-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/26100514-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/26100514-670x670.jpg 670w, https://themify.me/demo/themes/flat/files/2013/07/26100514-978x978.jpg 978w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/dark-gallery/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/70502623-221x221.jpg" width="221" height="221" alt="70502623" srcset="https://themify.me/demo/themes/flat/files/2013/07/70502623-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/70502623-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/70502623-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/70502623-240x240.jpg 240w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/dark-gallery/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/74418763-221x221.jpg" width="221" height="221" alt="74418763" srcset="https://themify.me/demo/themes/flat/files/2013/07/74418763-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/74418763-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/74418763-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/74418763-240x240.jpg 240w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/dark-gallery/">Dark Gallery</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=157&#038;action=edit">Edit</a>] </article>
<article id="portfolio-65"> <ul data-id="portfolio-slider-651" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/watercolor/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-221x221.jpg" width="221" height="221" alt="shutterstock_110864450" srcset="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_110864450-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/watercolor/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-221x221.jpg" width="221" height="221" alt="shutterstock_59513041" srcset="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59513041-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/watercolor/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-221x221.jpg" width="221" height="221" alt="shutterstock_59623786" srcset="https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/shutterstock_59623786-978x978.jpg 978w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/watercolor/">Watercolor</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=65&#038;action=edit">Edit</a>] </article>
<article id="portfolio-63"> <ul data-id="portfolio-slider-631" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/red-rose/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/639828071-221x221.jpg" width="221" height="221" alt="63982807" srcset="https://themify.me/demo/themes/flat/files/2013/07/639828071-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/639828071-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/639828071-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/639828071-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/red-rose/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/63637366-221x221.jpg" width="221" height="221" alt="63637366" srcset="https://themify.me/demo/themes/flat/files/2013/07/63637366-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/63637366-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/63637366-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/63637366-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/63637366-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/63637366-242x242.jpg 242w, https://themify.me/demo/themes/flat/files/2013/07/63637366-518x518.jpg 518w, https://themify.me/demo/themes/flat/files/2013/07/63637366-335x335.jpg 335w, https://themify.me/demo/themes/flat/files/2013/07/63637366.jpg 1000w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/red-rose/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/68392120-221x221.jpg" width="221" height="221" alt="68392120" srcset="https://themify.me/demo/themes/flat/files/2013/07/68392120-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/68392120-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/68392120-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/68392120-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/red-rose/">Red Rose</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=63&#038;action=edit">Edit</a>] </article>
<article id="portfolio-151"> <ul data-id="portfolio-slider-1511" data-autoplay="4000" data-effect="slide" data-speed="500"> <li> <a href="https://themify.me/demo/themes/flat/project/black-white/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/89686039-221x221.jpg" width="221" height="221" alt="89686039" srcset="https://themify.me/demo/themes/flat/files/2013/07/89686039-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/89686039-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/89686039-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/89686039-640x640.jpg 640w, https://themify.me/demo/themes/flat/files/2013/07/89686039-670x670.jpg 670w, https://themify.me/demo/themes/flat/files/2013/07/89686039-978x978.jpg 978w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/black-white/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/97479520-221x221.jpg" width="221" height="221" alt="97479520" srcset="https://themify.me/demo/themes/flat/files/2013/07/97479520-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/97479520-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/97479520-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/97479520-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> <li> <a href="https://themify.me/demo/themes/flat/project/black-white/"> <img src="https://themify.me/demo/themes/flat/files/2013/07/dv1483002-221x221.jpg" width="221" height="221" alt="dv1483002" srcset="https://themify.me/demo/themes/flat/files/2013/07/dv1483002-221x221.jpg 221w, https://themify.me/demo/themes/flat/files/2013/07/dv1483002-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/dv1483002-240x240.jpg 240w, https://themify.me/demo/themes/flat/files/2013/07/dv1483002-640x640.jpg 640w" sizes="(max-width: 221px) 100vw, 221px" /> </a> </li> </ul> <h2><a href="https://themify.me/demo/themes/flat/project/black-white/">Black &#038; White</a> </h2> 
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=151&#038;action=edit">Edit</a>] </article>
 <h2 style="text-align: center;">Feature</h2>
 <h3>Attract viewer attention by showing animated circle Feature modules (great for highlighting services or product features).</h3>
 
 
 
 
 <h3> Web Design </h3> <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor.</p> 
 
 
 
 
 
 <h3> Development </h3> <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor.Praesent venenatis purus.</p> 
 
 
 
 
 
 <h3> E-Commerce </h3> <p>Proin et rutrum dolor. Proin et rutrum dolor.Praesent venenatis purus.</p> 
 
 
 
 
 
 <h3> Advertising </h3> <p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.</p> 
 
 <h2 style="text-align: center;">Progress Bar</h2>
 <h3>Progress bar can be used to show animated color bars such as team member skills or status bars. You can customize the color, label text, and the length of the bar.</h3> <i>Web Design</i> <i>Sales Performance</i> <i>Site Construction</i> <i>Redesign Progress</i> <i>Customer Satisfaction </i>
 <h2 style="text-align: center;">Timeline</h2>
 <p style="text-align: center;"><ul> <li id="timeline-192"> <h3> Apr 2002 </h3> 
 &bull; 
 
 
 
 <p>Started freelancing.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=192&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-195"> <h3> Aug 2010 </h3> 
 &bull; 
 
 
 
 <p>Launched <a href="https://themify.me">Themify</a></p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=195&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-197"> <h3> Nov 2012 </h3> 
 &bull; 
 
 
 
 <p>Themify redesign started</p> <i>Main Wireframe</i>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=197&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-201"> <h3> May 2013 </h3> 
 &bull; 
 
 
 
 <p>Themify redesign main layout done</p> <i>Mockup Design</i>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=201&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
<li id="timeline-199"> <h3> Jul 2013 </h3> 
 &bull; 
 
 
 <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/themify-site-400x276.jpg" width="400" alt="themify site" srcset="https://themify.me/demo/themes/flat/files/2013/07/themify-site-400x276.jpg 400w, https://themify.me/demo/themes/flat/files/2013/07/themify-site-300x207.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/themify-site.jpg 800w" sizes="(max-width: 400px) 100vw, 400px" /> </figure> 
 <p>Themify Builder launched</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=199&#038;action=edit">Edit Timeline Entry</a>] 
 </li>
</ul>
</p>
 <h2 style="text-align: center;">Team</h2>
 <h3 style="text-align: center;">Show off your team member skills with animated color bars</h3> <article id="team-48"> 
 <figure> <a href="https://themify.me/demo/themes/flat/team/amy-weaver/" title="Amy Weaver"> <img src="https://themify.me/demo/themes/flat/files/2013/07/86527867-144x144.jpg" width="144" height="144" alt="86527867" srcset="https://themify.me/demo/themes/flat/files/2013/07/86527867-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/86527867-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/86527867-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/86527867-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/86527867.jpg 667w" sizes="(max-width: 144px) 100vw, 144px" /> </a> </figure> 
 <h1> <a href="https://themify.me/demo/themes/flat/team/amy-weaver/" title="Amy Weaver"> Amy Weaver </a> Project Manager </h1> 
 <p>Maecenas luctus aliquet risus ac feugiat. Curabitur enim mi, placerat sit amet porttitor ac, mollis lobortis elit. Cras sit amet erat eget dolor varius tristique. Duis eu nisl tortor. Mauris pulvinar metus eget nulla adipiscing consectetur.</p>
 
 <p> <a href="http://twitter.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png" alt="social-link" /></a>
<a href="http://facebook.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png" alt="social-link" /></a>
<a href="http://pinterest.com/"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png" alt="social-link" /></a> </p> 
 
 <i>Project Management</i>
 <i>Marketing</i>
 <i>Logistics</i> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=48&#038;action=edit">Edit Team</a>] </article>
<article id="team-45"> 
 <figure> <a href="https://themify.me/demo/themes/flat/team/jacqueline-willis/" title="Jacqueline Willis"> <img src="https://themify.me/demo/themes/flat/files/2013/07/84008631-144x144.jpg" width="144" height="144" alt="84008631" srcset="https://themify.me/demo/themes/flat/files/2013/07/84008631-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/84008631-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/84008631-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/84008631-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/84008631.jpg 548w" sizes="(max-width: 144px) 100vw, 144px" /> </a> </figure> 
 <h1> <a href="https://themify.me/demo/themes/flat/team/jacqueline-willis/" title="Jacqueline Willis"> Jacqueline Willis </a> Web Designer </h1> 
 <p>Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. dolor quis sollicitudin accumsan, elit turpis tempor est mattis.</p>
 
 <p> <a href="http://twitter.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png" alt="social-link" /></a>
<a href="http://facebook.com/themify"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png" alt="social-link" /></a>
<a href="http://pinterest.com/"><img src="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png" alt="social-link" /></a> </p> 
 
 <i>Graphic Design</i>
 <i>Web Design</i>
 <i>jQuery</i> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=45&#038;action=edit">Edit Team</a>] </article>
 <h2 style="text-align: center;">Testimonial</h2>
 <h3 style="text-align: center;">Customer Testimonials can be displayed in various layouts: slider, grid, and list post style.</h3><ul data-id="testimonial-slider-1" data-autoplay="4000" data-effect="slide" data-speed="500"> <li>
<article id="testimonial-22"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/82152160-144x144.jpg" width="144" height="144" alt="82152160" srcset="https://themify.me/demo/themes/flat/files/2013/07/82152160-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/82152160-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/82152160-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/82152160-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/82152160-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/82152160.jpg 369w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Diana Jones</h1> <p>Maecenas in orci nunc. Curabitur velit sapien, mollis vel aliquam et, dignissim consequat eros. Curabitur egestas quam dapibus arcu egestas mollis.</p>
 
 <p> Diana Jones &ndash; CEO, Nice Company </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=22&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-20"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/112268515-144x144.jpg" width="144" height="144" alt="112268515" srcset="https://themify.me/demo/themes/flat/files/2013/07/112268515-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/112268515-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/112268515-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/112268515-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/112268515-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/112268515.jpg 577w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Amanda Elric</h1> <p>Rravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop’s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.</p>
 
 <p> Amanda Elric &ndash; Manager, Themify </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=20&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-12"> <figure> <img src="https://themify.me/demo/themes/flat/files/2013/07/124661612-144x144.jpg" width="144" height="144" alt="124661612" srcset="https://themify.me/demo/themes/flat/files/2013/07/124661612-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2013/07/124661612-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/124661612-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2013/07/124661612-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2013/07/124661612.jpg 373w, https://themify.me/demo/themes/flat/files/2013/07/124661612-978x978.jpg 978w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Mike Canlas</h1> <p>Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop&#8217;s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.</p>
 
 <p> Mike Canlas &ndash; Owner </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=12&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li>
 <li>
<article id="testimonial-1592"> <figure> <img src="https://themify.me/demo/themes/flat/files/2012/11/105942619-144x144.jpg" width="144" height="144" alt="105942619" srcset="https://themify.me/demo/themes/flat/files/2012/11/105942619-144x144.jpg 144w, https://themify.me/demo/themes/flat/files/2012/11/105942619-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2012/11/105942619-300x300.jpg 300w, https://themify.me/demo/themes/flat/files/2012/11/105942619-80x80.jpg 80w, https://themify.me/demo/themes/flat/files/2012/11/105942619-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2012/11/105942619.jpg 306w" sizes="(max-width: 144px) 100vw, 144px" /> </figure> 
 <h1>Exceeded Our Expectation</h1> <p>Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla. Fusce ut sem est. In eu sagittis felis. In gravida arcu ut neque ornare vitae rutrum tu. Cras a fringilla nunc. Suspendisse volutpat, eros cong rpis vehicula.</p>
 
 <p> Vanissa &ndash; Manager </p> [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=1592&#038;action=edit">Edit Testimonial</a>] 
 </article>
 </li> </ul>
 <h2 style="text-align: center;">Blog</h2>
 <h3 style="text-align: center;">Seven blog layout options are available from list post style to various grid layouts</h3>
<article id="post-2178"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/the-canyon/"><img src="https://themify.me/demo/themes/flat/files/2013/07/136056098-145x145.jpg" width="145" height="145" alt="136056098" srcset="https://themify.me/demo/themes/flat/files/2013/07/136056098-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/136056098-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/136056098-100x100.jpg 100w, https://themify.me/demo/themes/flat/files/2013/07/136056098-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/136056098-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/136056098-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/136056098-670x670.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/the-canyon/">The Canyon</a> </h2> 
 <p>Pellentesque ipsum nisi, rhoncus dictum magna at, adipiscing commodo magna. Aenean accumsan erat a lacus semper, nec vulputate magna euismod. Maecenas a lacus rhoncus, ullamcorper sem consectetur, mollis lacus.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2178&#038;action=edit">Edit</a>] </article>
<article id="post-2167"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/vegetable-fun/"><img src="https://themify.me/demo/themes/flat/files/2013/07/132261116-145x145.jpg" width="145" height="145" alt="132261116" srcset="https://themify.me/demo/themes/flat/files/2013/07/132261116-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/132261116-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/132261116-100x100.jpg 100w, https://themify.me/demo/themes/flat/files/2013/07/132261116-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/132261116-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/132261116-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/132261116-670x667.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/vegetable-fun/">Vegetable Fun</a> </h2> 
 <p>Donec id lectus sed risus fermentum auctor. In fringilla nulla tincidunt congue vulputate. Donec auctor risus ut elit pretium, ultrices iaculis velit interdum.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2167&#038;action=edit">Edit</a>] </article>
<article id="post-2164"> <figure> <a href="https://themify.me/demo/themes/flat/2013/07/16/needed-vacation/"><img src="https://themify.me/demo/themes/flat/files/2013/07/128686832-145x145.jpg" width="145" height="145" alt="128686832" srcset="https://themify.me/demo/themes/flat/files/2013/07/128686832-145x145.jpg 145w, https://themify.me/demo/themes/flat/files/2013/07/128686832-150x150.jpg 150w, https://themify.me/demo/themes/flat/files/2013/07/128686832-60x60.jpg 60w, https://themify.me/demo/themes/flat/files/2013/07/128686832-200x200.jpg 200w, https://themify.me/demo/themes/flat/files/2013/07/128686832-978x978.jpg 978w, https://themify.me/demo/themes/flat/files/2013/07/128686832-670x666.jpg 670w" sizes="(max-width: 145px) 100vw, 145px" /></a> </figure>
 
 <h2><a href="https://themify.me/demo/themes/flat/2013/07/16/needed-vacation/">Needed Vacation</a> </h2> 
 <p>Donec tincidunt et massa sit amet sodales. In cursus augue ac sem ornare, eu interdum odio volutpat. Donec odio quam, lacinia quis nibh at, bibendum fringilla ante.</p>
 
 [<a href="https://themify.me/demo/themes/flat/wp-admin/post.php?post=2164&#038;action=edit">Edit</a>] </article>
 <h2 style="text-align: center;">Beautifully Designed</h2>
 <h3>Flat theme is beautifully designed &#038; coded with many visual effects such as: fade-in, fly-in, animated bar, circle animation, etc.</h3><a href="https://themify.me/themes/flat">GET IT NOW</a><!--/themify_builder_static-->',
  'post_title' => 'Features',
  'post_excerpt' => '',
  'post_name' => 'features',
  'post_modified' => '2018-03-06 23:50:47',
  'post_modified_gmt' => '2018-03-06 23:50:47',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2367',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'posts_per_page' => '1',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Theme Features<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>This demo page highlights the main features of <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/flat\\\\\\\\\\\\\\">Flat<\\\\/a> theme.<\\\\/h3><p>[button style=\\\\\\\\\\\\\\"large rounded flat\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/flat\\\\\\\\\\\\\\"]Get Flat Theme Now[\\\\/button]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"59ade3_1.00\\",\\"font_color\\":\\"c9e9ff_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"fffbc8_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Builder Rows<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>What you see on this page is constructed with Builder modules. The Builder modules comes with styling panels that allows you to customize the color, font, padding, margins, and background on each module. For this row we used a Text module in Heading 3, to display this text.<\\\\/h3>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"fff457_1.00\\",\\"font_color\\":\\"9e8b21_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Themify Builder<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Themify Builder provides easy to use user interface which allows you to arrange the content blocks on the frontend by dragging and dropping. In other words, what you see is what you get. The content blocks can be built using various modules: Text, Slider, Video, Image, Post, Gallery, Tab, Accordion, Menu, etc.<\\\\/h3><p>[button style=\\\\\\\\\\\\\\"large rounded flat black\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/flat\\\\/builder-demos\\\\/\\\\\\\\\\\\\\"]Builder Demos[\\\\/button]<\\\\/p>\\"}},{\\"mod_name\\":\\"video\\",\\"mod_settings\\":{\\"style_video\\":\\"video-top\\",\\"url_video\\":\\"http:\\\\/\\\\/www.youtube.com\\\\/watch?v=hHw6VKKjcpQ\\",\\"width_video\\":\\"100\\",\\"unit_video\\":\\"%\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"fa5ba5_1.00\\",\\"font_color\\":\\"fde1ee_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"fff89f_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Portfolio<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Showcase your work with Portfolio custom post type. You can display either image slider or a single featured image.<\\\\/h3><p>[portfolio category=\\\\\\\\\\\\\\"featured\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"grid4\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"9eff36_1.00\\",\\"font_color\\":\\"6e8159_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Feature<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Attract viewer attention by showing animated circle Feature modules (great for highlighting services or product features).<\\\\/h3>\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Web Design\\",\\"content_feature\\":\\"<p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"90\\",\\"circle_stroke_feature\\":\\"25\\",\\"circle_color_feature\\":\\"FCA8BC\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-desktop\\",\\"icon_color_feature\\":\\"9c9c9c_1.00\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Development\\",\\"content_feature\\":\\"<p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor.Praesent venenatis purus.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"70\\",\\"circle_stroke_feature\\":\\"25\\",\\"circle_color_feature\\":\\"02DAAF\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-wrench\\",\\"icon_color_feature\\":\\"9c9c9c_1.00\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"E-Commerce\\",\\"content_feature\\":\\"<p>Proin et rutrum dolor. Proin et rutrum dolor.Praesent venenatis purus.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"60\\",\\"circle_stroke_feature\\":\\"25\\",\\"circle_color_feature\\":\\"22D9E5\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-shopping-cart\\",\\"icon_color_feature\\":\\"9c9c9c_1.00\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Advertising\\",\\"content_feature\\":\\"<p>Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"80\\",\\"circle_stroke_feature\\":\\"25\\",\\"circle_color_feature\\":\\"C594DA\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-line-chart\\",\\"icon_color_feature\\":\\"9c9c9c_1.00\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"d4f2ff_1.00\\",\\"font_color\\":\\"586c75_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Progress Bar<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Progress bar can be used to show animated color bars such as team member skills or status bars. You can customize the color, label text, and the length of the bar.<\\\\/h3><p>[progress_bar label=\\\\\\\\\\\\\\"Web Design\\\\\\\\\\\\\\" color=\\\\\\\\\\\\\\"#ff6c6d\\\\\\\\\\\\\\" percentage=\\\\\\\\\\\\\\"90\\\\\\\\\\\\\\"]<\\\\/p><p>[progress_bar label=\\\\\\\\\\\\\\"Sales Performance\\\\\\\\\\\\\\" color=\\\\\\\\\\\\\\"#c799ff\\\\\\\\\\\\\\" percentage=\\\\\\\\\\\\\\"80\\\\\\\\\\\\\\"]<\\\\/p><p>[progress_bar label=\\\\\\\\\\\\\\"Site Construction\\\\\\\\\\\\\\" color=\\\\\\\\\\\\\\"#2b99ee\\\\\\\\\\\\\\" percentage=\\\\\\\\\\\\\\"60\\\\\\\\\\\\\\"]<\\\\/p><p>[progress_bar label=\\\\\\\\\\\\\\"Redesign Progress\\\\\\\\\\\\\\" color=\\\\\\\\\\\\\\"#ee5b92\\\\\\\\\\\\\\" percentage=\\\\\\\\\\\\\\"50\\\\\\\\\\\\\\"]<\\\\/p><p>[progress_bar label=\\\\\\\\\\\\\\"Customer Satisfaction \\\\\\\\\\\\\\" color=\\\\\\\\\\\\\\"#a0ed4d\\\\\\\\\\\\\\" percentage=\\\\\\\\\\\\\\"100\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"60e7ff_1.00\\",\\"font_color\\":\\"4a7b90_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Timeline<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">[timeline category=\\\\\\\\\\\\\\"personal-timeline\\\\\\\\\\\\\\" order=\\\\\\\\\\\\\\"ASC\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"10\\\\\\\\\\\\\\" use_original_dimensions=\\\\\\\\\\\\\\"yes\\\\\\\\\\\\\\"]<\\\\/p>\\\\n\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"fe5618_1.00\\",\\"font_color\\":\\"ffd2c2_1.00\\",\\"link_color\\":\\"fffbce_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Team<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Show off your team member skills with animated color bars<\\\\/h3><p>[team style=\\\\\\\\\\\\\\"list-post\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"6689d3_1.00\\",\\"font_color\\":\\"d2e0ff_1.00\\",\\"link_color\\":\\"fff6d1_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Testimonial<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Customer Testimonials can be displayed in various layouts: slider, grid, and list post style.<\\\\/h3><p>[testimonial style=\\\\\\\\\\\\\\"slider\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"4\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"a357e6_1.00\\",\\"font_color\\":\\"ecc7ff_1.00\\",\\"link_color\\":\\"fffea5_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Blog<\\\\/h2>\\",\\"font_color\\":\\"000000_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Seven blog layout options are available from list post style to various grid layouts<\\\\/h3><p>[list_posts limit=\\\\\\\\\\\\\\"3\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"list-post circle-image\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"145\\\\\\\\\\\\\\" display=\\\\\\\\\\\\\\"excerpt\\\\\\\\\\\\\\" post_date=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\"]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"aec1e3_1.00\\",\\"font_color\\":\\"717a89_1.00\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"10\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Beautifully Designed<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Flat theme is beautifully designed & coded with many visual effects such as: fade-in, fly-in, animated bar, circle animation, etc.<\\\\/h3><p>[button link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/flat\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"flat rounded xlarge red\\\\\\\\\\\\\\"]GET IT NOW[\\\\/button]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"303030_1.00\\",\\"font_color\\":\\"cfcfcf_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"d1fdff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"11\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2379,
  'post_date' => '2014-10-02 22:33:31',
  'post_date_gmt' => '2014-10-02 22:33:31',
  'post_content' => '',
  'post_title' => 'Software Page Demo',
  'post_excerpt' => '',
  'post_name' => 'software-page',
  'post_modified' => '2017-08-21 11:33:02',
  'post_modified_gmt' => '2017-08-21 11:33:02',
  'post_content_filtered' => '',
  'post_parent' => 2369,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2379',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Themify Builder</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat/files/2013/07/themify-builder.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"978\\",\\"link_image\\":\\"http://www.youtube.com/watch?v=hHw6VKKjcpQ\\",\\"param_image\\":\\"lightbox|zoom\\",\\"caption_image\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">All Themify WordPress themes now include the ability to create designs for your website by dragging and dropping. Build beautiful, responsive layouts that work for desktop, tablets, and mobile using our intuitive \\\\\\\\\\\'what you see is what you get\\\\\\\\\\\' drag & drop framework with live edits and previews.</h3>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">[button link=\\\\\\\\\\\'https://themify.me/demo/themes/builder\\\\\\\\\\\' style=\\\\\\\\\\\'xlarge green rounded flat\\\\\\\\\\\']View Demo[/button] [button link=\\\\\\\\\\\'https://themify.me\\\\\\\\\\\' style=\\\\\\\\\\\'xlarge blue rounded flat\\\\\\\\\\\']Browse Themes[/button]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"slide-up\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"5b4888_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"cac3dd_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"ffffc7_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Get it Now</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Themify\\\\\\\\\\\'s drag & drop framework is now included in all themes</p><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">[button link=\\\\\\\\\\\\\\"https://themify.me\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"xlarge rounded flat\\\\\\\\\\\\\\"]Browse Themes[/button]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"slide-up\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"adebfc_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"455e65_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Builder Features</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2013/07/builder-interface.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"title_image\\":\\"Live Edits & Previews\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"Themify Builder is super easy to use. To start: simply dorp in a module, configure the options and the actual content will appear instantly on the page. You can then rearrange the content block, rows, and grids by dragging. It works with static content (text, images, videos, etc.) and dynamic content such as displaying posts from the database or running shortcodes.\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2013/07/builder-layouts.png\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"title_image\\":\\"What Can You Build With The Builder?\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"The layouts that you can build with Themify Builder are unlimited. Check this demo site that we built with Themify Builder. You can design any layout type from a simple portfolio page to a business homepage or large complex grid layouts.\\",\\"animation_effect\\":\\"fadeInRight\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https://themify.me/demo/themes/flat/files/2013/07/parallax-responsive-design.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"title_image\\":\\"Responsive\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"Responsive designs that work on desktop, tablet, and mobile browsers. Nullam facilisis non massa eu dapibus. Nulla commodo varius neque, convallis venenatis odio ultrices in. Etiam interdum molestie quam nec dapibus. Aenean dictum volutpat luctus. Nulla at varius metus. Sed lacinia viverra eros, eget imperdiet est commodo eu.\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"1dc871_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"c1f6db_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"f2c308_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Showcase</h2>\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https://themify.me/demo/themes/flat/files/2013/07/mad-1024x533.png\\",\\"img_title_slider\\":\\"Slide One\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/flat/files/2013/07/Juliana-Bicycles-The-Original-Womens-Mountain-Bike-1024x570.png\\",\\"img_title_slider\\":\\"Slide Two\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/flat/files/2013/07/mad1-1024x533.png\\",\\"img_title_slider\\":\\"Slide Three\\"}],\\"layout_slider\\":\\"slider-default\\",\\"img_w_slider\\":\\"550\\",\\"img_h_slider\\":\\"550\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_video\\":\\"\\",\\"background_color\\":\\"ea533b_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffe5e1_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"fffbbf_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2210,
  'post_date' => '2013-10-11 19:06:23',
  'post_date_gmt' => '2013-10-11 19:06:23',
  'post_content' => '',
  'post_title' => 'Portfolio - 3 Columns',
  'post_excerpt' => '',
  'post_name' => 'portfolio-3-columns',
  'post_modified' => '2017-08-21 11:33:07',
  'post_modified_gmt' => '2017-08-21 11:33:07',
  'post_content_filtered' => '',
  'post_parent' => 2172,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2210',
  'menu_order' => 3,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid3',
    'portfolio_posts_per_page' => '9',
    'portfolio_display_content' => 'none',
    'portfolio_image_width' => '335',
    'portfolio_image_height' => '335',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2212,
  'post_date' => '2013-10-11 19:07:08',
  'post_date_gmt' => '2013-10-11 19:07:08',
  'post_content' => '',
  'post_title' => 'Portfolio - 2 Columns',
  'post_excerpt' => '',
  'post_name' => 'portfolio-2-columns',
  'post_modified' => '2017-08-21 11:33:05',
  'post_modified_gmt' => '2017-08-21 11:33:05',
  'post_content_filtered' => '',
  'post_parent' => 2172,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2212',
  'menu_order' => 3,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid2',
    'portfolio_posts_per_page' => '6',
    'portfolio_display_content' => 'none',
    'portfolio_image_width' => '518',
    'portfolio_image_height' => '518',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2172,
  'post_date' => '2013-07-16 19:14:30',
  'post_date_gmt' => '2013-07-16 19:14:30',
  'post_content' => '',
  'post_title' => 'Portfolio',
  'post_excerpt' => '',
  'post_name' => 'portfolio',
  'post_modified' => '2017-08-21 11:33:03',
  'post_modified_gmt' => '2017-08-21 11:33:03',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2172',
  'menu_order' => 3,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_posts_per_page' => '12',
    'portfolio_display_content' => 'none',
    'portfolio_image_width' => '242',
    'portfolio_image_height' => '242',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2208,
  'post_date' => '2013-10-11 18:59:02',
  'post_date_gmt' => '2013-10-11 18:59:02',
  'post_content' => '',
  'post_title' => 'Blog - 2 Columns',
  'post_excerpt' => '',
  'post_name' => 'blog-2-columns',
  'post_modified' => '2017-08-21 11:33:12',
  'post_modified_gmt' => '2017-08-21 11:33:12',
  'post_content_filtered' => '',
  'post_parent' => 2156,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2208',
  'menu_order' => 4,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid2',
    'posts_per_page' => '12',
    'display_content' => 'excerpt',
    'image_width' => '512',
    'image_height' => '330',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2203,
  'post_date' => '2013-10-11 18:46:39',
  'post_date_gmt' => '2013-10-11 18:46:39',
  'post_content' => '',
  'post_title' => 'Blog - 4 Columns',
  'post_excerpt' => '',
  'post_name' => 'blog-4-columns',
  'post_modified' => '2017-08-21 11:33:14',
  'post_modified_gmt' => '2017-08-21 11:33:14',
  'post_content_filtered' => '',
  'post_parent' => 2156,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2203',
  'menu_order' => 4,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid4',
    'posts_per_page' => '12',
    'display_content' => 'none',
    'image_width' => '236',
    'image_height' => '170',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta_all' => 'yes',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2156,
  'post_date' => '2013-07-15 23:30:22',
  'post_date_gmt' => '2013-07-15 23:30:22',
  'post_content' => '',
  'post_title' => 'Blog',
  'post_excerpt' => '',
  'post_name' => 'blog',
  'post_modified' => '2017-08-21 11:33:08',
  'post_modified_gmt' => '2017-08-21 11:33:08',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2156',
  'menu_order' => 4,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-thumb-image',
    'posts_per_page' => '6',
    'display_content' => 'content',
    'image_width' => '200',
    'image_height' => '200',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2132,
  'post_date' => '2013-07-15 21:50:59',
  'post_date_gmt' => '2013-07-15 21:50:59',
  'post_content' => '<h3>Here are some of the <a href="https://themify.me/docs/shortcodes">shortcodes</a> packed with the Themify framework:</h3>
<h3>Buttons</h3>
[button style="orange" link="https://themify.me"]Orange[/button] [button style="blue"]Blue[/button] [button style="pink"]Pink[/button] [button style="green"]Green[/button] [button style="red"]Red[/button] [button style="black"]Black[/button]

[hr]

[button style="small"]Small[/button]

[button]Default[/button]

[button style="large"]Large[/button] [button style="xlarge"]Xlarge[/button]

[hr]

[button style="orange small"]Orange Small[/button] [button style="blue"]Blue[/button] [button style="green large"]Green Large[/button] [button style="red xlarge"]Red Xlarge[/button]

[hr]
<h3>Columns</h3>
[col grid="2-1 first"]
<h4>col 2-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg.

[/col]

[col grid="2-1"]
<h4>col 2-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa.

[/col]

[hr]

[col grid="3-1 first"]
<h4>col 3-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg.

[/col]

[col grid="3-1"]
<h4>col 3-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa.

[/col]

[col grid="3-1"]
<h4>col 3-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit.

[/col]

[hr]

[col grid="4-1 first"]
<h4>col 4-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget co.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit diam.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Donec porttitor hendrerit diam et blandit. Curabitur vel risus eros, sed eleifend arcu. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[hr]

[col grid="4-2 first"]
<h4>col 4-2</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget cout rhoncus turpis augue vitae libero.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit diam.

[/col]
<h3>Horizontal Rules</h3>
[hr]

[hr color="pink"]

[hr color="red"]

[hr color="light-gray"]

[hr color="dark-gray"]

[hr color="black"]

[hr color="orange"]

[hr color="yellow"]

[hr color="white"]
<h3>Quote</h3>
[quote]Vivamus in risus non lacus vehicula vestibulum. In magna leo, malesuada eget pulvinar ut, pellentesque a arcu. Praesent rutrum feugiat nibh elementum posuere. Nulla volutpat porta enim vel consectetur. Etiam orci eros, blandit nec egestas eget, pharetra eget leo. Morbi lobortis adipiscing massa tincidunt dignissim. Nulla lobortis laoreet risus, tempor accumsan sem congue vitae. Cras laoreet hendrerit erat, id porttitor nunc blandit adipiscing. [/quote]
<h3>Map</h3>
[map address="Yonge St. and Eglinton Ave, Toronto, Ontario, Canada" width=100% height=400px]

[hr]
<h3>Flickr</h3>
[flickr user="52839779@N02" limit="6"]

[hr]
<h3>Twitter</h3>
[twitter username="themify" show_count="3" show_follow="true" follow_text="Follow Themify"]

[hr]
<h3>Post Slider</h3>
[post_slider limit="6" image="yes" image_w="300" image_h="200" visible="4" scroll="1"]

[hr]
<h3>Slider</h3>
[slider auto="1" scroll="1" speed="fast"]
[slide] <strong>slide one</strong> [/slide]
[slide] <strong>slide two</strong> [/slide]
[slide] <strong>slide three</strong> [/slide]
[/slider]

[hr]
<h3>List Post</h3>
[list_posts limit="4" image="yes" style="grid4 fly-in"]

[hr]
<h3>Box</h3>
[box style="yellow rounded flat"] <strong>box content</strong> [/box]

[hr]
<h3>Author Box</h3>
[author_box style="light-yellow rounded flat" avatar="yes" avatar_size="56" author_link="yes"]',
  'post_title' => 'Shortcodes',
  'post_excerpt' => '',
  'post_name' => 'shortcodes',
  'post_modified' => '2017-08-21 11:33:16',
  'post_modified_gmt' => '2017-08-21 11:33:16',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?page_id=2132',
  'menu_order' => 6,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_date' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 36,
  'post_date' => '2013-07-12 04:52:24',
  'post_date_gmt' => '2013-07-12 04:52:24',
  'post_content' => 'Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.',
  'post_title' => 'Advertising',
  'post_excerpt' => '',
  'post_name' => 'advertising',
  'post_modified' => '2017-08-21 11:34:05',
  'post_modified_gmt' => '2017-08-21 11:34:05',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=highlight&#038;p=36',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
    'bar_percentage' => '70',
    'bar_color' => '#c594da',
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 38,
  'post_date' => '2013-07-12 04:53:47',
  'post_date_gmt' => '2013-07-12 04:53:47',
  'post_content' => 'Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.',
  'post_title' => 'E-commerce',
  'post_excerpt' => '',
  'post_name' => 'e-commerce',
  'post_modified' => '2017-08-21 11:34:03',
  'post_modified_gmt' => '2017-08-21 11:34:03',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=highlight&#038;p=38',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
    'bar_percentage' => '75',
    'bar_color' => '#22d9e5',
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 40,
  'post_date' => '2013-07-12 04:55:25',
  'post_date_gmt' => '2013-07-12 04:55:25',
  'post_content' => 'Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor. Praesent venenatis purus.',
  'post_title' => 'Development',
  'post_excerpt' => '',
  'post_name' => 'development',
  'post_modified' => '2017-08-21 11:34:01',
  'post_modified_gmt' => '2017-08-21 11:34:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=highlight&#038;p=40',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
    'bar_percentage' => '80',
    'bar_color' => '#02daaf',
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 42,
  'post_date' => '2013-07-12 04:56:16',
  'post_date_gmt' => '2013-07-12 04:56:16',
  'post_content' => 'Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Proin et rutrum dolor.',
  'post_title' => 'Web Design',
  'post_excerpt' => '',
  'post_name' => 'web-design',
  'post_modified' => '2017-08-21 11:33:59',
  'post_modified_gmt' => '2017-08-21 11:33:59',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=highlight&#038;p=42',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
    'bar_percentage' => '95',
    'bar_color' => '#fca8bc',
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2074,
  'post_date' => '2008-10-02 23:10:02',
  'post_date_gmt' => '2008-10-02 23:10:02',
  'post_content' => 'In gravida arcu ut neque ornare vitae sem mollis metus rutrum non malesuada metus fermentum.',
  'post_title' => 'eCommerce',
  'post_excerpt' => '',
  'post_name' => 'ecommerce',
  'post_modified' => '2017-08-21 11:34:22',
  'post_modified_gmt' => '2017-08-21 11:34:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=123',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2075,
  'post_date' => '2008-10-03 23:11:57',
  'post_date_gmt' => '2008-10-03 23:11:57',
  'post_content' => 'Vestibulum congue nisl magna. Ut vulputate odio id dui convallis in adipiscing libero condiment.',
  'post_title' => 'Security',
  'post_excerpt' => '',
  'post_name' => 'security',
  'post_modified' => '2017-08-21 11:34:19',
  'post_modified_gmt' => '2017-08-21 11:34:19',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=126',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2076,
  'post_date' => '2008-10-04 23:12:56',
  'post_date_gmt' => '2008-10-04 23:12:56',
  'post_content' => 'Sodales dui, vitae vulputate elit metus ac arcu. Mauris consequat rhoncus dolor id sagittis.',
  'post_title' => 'Invoice &amp; Reports',
  'post_excerpt' => '',
  'post_name' => 'invoice-reports',
  'post_modified' => '2017-08-21 11:34:18',
  'post_modified_gmt' => '2017-08-21 11:34:18',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=128',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2077,
  'post_date' => '2008-10-07 23:15:08',
  'post_date_gmt' => '2008-10-07 23:15:08',
  'post_content' => 'Aliquam erat nulla, sodales at imperdiet vitae, convallis vel des felis ut justo suscipit vestibulum.',
  'post_title' => 'Online Backup',
  'post_excerpt' => '',
  'post_name' => 'online-backup',
  'post_modified' => '2017-08-21 11:34:14',
  'post_modified_gmt' => '2017-08-21 11:34:14',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=132',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2078,
  'post_date' => '2008-09-01 23:16:04',
  'post_date_gmt' => '2008-09-01 23:16:04',
  'post_content' => 'Aliquam erat nulla, sodales at imperdiet vitae, convallisd ultrices felis ut justo suscipit vestibulum.',
  'post_title' => 'Android Compatible',
  'post_excerpt' => '',
  'post_name' => 'android-compatible',
  'post_modified' => '2017-08-21 11:34:27',
  'post_modified_gmt' => '2017-08-21 11:34:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=134',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'features',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2079,
  'post_date' => '2008-09-02 23:24:50',
  'post_date_gmt' => '2008-09-02 23:24:50',
  'post_content' => 'Sed sagittis, elit egestas rutrum vehicul ue dolor fringilla lacus, ut rhoncus turpis augue vitae libero.',
  'post_title' => 'iOS App',
  'post_excerpt' => '',
  'post_name' => 'ios-app',
  'post_modified' => '2017-08-21 11:34:25',
  'post_modified_gmt' => '2017-08-21 11:34:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=137',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'features',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1012,
  'post_date' => '2008-11-12 22:44:05',
  'post_date_gmt' => '2008-11-12 22:44:05',
  'post_content' => 'Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero.',
  'post_title' => 'App Store',
  'post_excerpt' => '',
  'post_name' => 'app-store',
  'post_modified' => '2017-08-21 11:34:12',
  'post_modified_gmt' => '2017-08-21 11:34:12',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=1012',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'features',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1015,
  'post_date' => '2008-11-12 22:48:21',
  'post_date_gmt' => '2008-11-12 22:48:21',
  'post_content' => 'In gravida arcu ut neque ornare vitae rut primis in faucibus to rpri mis in faucibus um turpis vehicula.',
  'post_title' => 'Geo Locator',
  'post_excerpt' => '',
  'post_name' => 'geo-locator',
  'post_modified' => '2017-08-21 11:34:10',
  'post_modified_gmt' => '2017-08-21 11:34:10',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=1015',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'features',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1017,
  'post_date' => '2008-11-12 22:49:47',
  'post_date_gmt' => '2008-11-12 22:49:47',
  'post_content' => 'Mauris consequat rhoncus dolor id sagittis. Cras tortor elit, aliquet quis dignissim non tortor.',
  'post_title' => 'Credit Cards',
  'post_excerpt' => '',
  'post_name' => 'credit-cards',
  'post_modified' => '2017-08-21 11:34:09',
  'post_modified_gmt' => '2017-08-21 11:34:09',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=1017',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'features',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1019,
  'post_date' => '2008-11-12 22:50:30',
  'post_date_gmt' => '2008-11-12 22:50:30',
  'post_content' => 'Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla. Fusce ut sem est. In eu sagittis felis.',
  'post_title' => 'Auto Sync',
  'post_excerpt' => '',
  'post_name' => 'wordpress-support',
  'post_modified' => '2017-08-21 11:34:07',
  'post_modified_gmt' => '2017-08-21 11:34:07',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=1019',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'features',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1322,
  'post_date' => '2008-10-01 23:09:29',
  'post_date_gmt' => '2008-10-01 23:09:29',
  'post_content' => 'Donec consequat eros eget lectus dictum sit amet ultrices neque sodales liquam metus diam.',
  'post_title' => 'SEO',
  'post_excerpt' => '',
  'post_name' => 'seo',
  'post_modified' => '2017-08-21 11:34:23',
  'post_modified_gmt' => '2017-08-21 11:34:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=121',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1323,
  'post_date' => '2008-10-06 23:14:22',
  'post_date_gmt' => '2008-10-06 23:14:22',
  'post_content' => 'Aliquam metus diam, mattis fringilla adi of the piscing at, lacinia at nulla. Fusce ut sem est.',
  'post_title' => 'Tablet',
  'post_excerpt' => '',
  'post_name' => 'tablet',
  'post_modified' => '2017-08-21 11:34:16',
  'post_modified_gmt' => '2017-08-21 11:34:16',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=highlight&#038;p=130',
  'menu_order' => 0,
  'post_type' => 'highlight',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'highlight-category' => 'services',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 45,
  'post_date' => '2013-07-12 05:00:25',
  'post_date_gmt' => '2013-07-12 05:00:25',
  'post_content' => 'Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. dolor quis sollicitudin accumsan, elit turpis tempor est mattis.',
  'post_title' => 'Jacqueline Willis',
  'post_excerpt' => '',
  'post_name' => 'jacqueline-willis',
  'post_modified' => '2017-08-21 11:34:58',
  'post_modified_gmt' => '2017-08-21 11:34:58',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=team&#038;p=45',
  'menu_order' => 0,
  'post_type' => 'team',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'team_title' => 'Web Designer',
    'skills' => '[progress_bar label="Graphic Design" percentage="80"]
[progress_bar label="Web Design" color="#c594da" percentage="58"]
[progress_bar label="jQuery" color="#22d9e5" percentage="69"]',
    'social' => '[team-social label="Twitter" link="http://twitter.com/themify" image="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png"]

[team-social label="Facebook" link="http://facebook.com/themify" image="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png"]

[team-social label="Pinterest" link="http://pinterest.com/" image="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png"]',
  ),
  'tax_input' => 
  array (
    'team-category' => 'uncategorized',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 48,
  'post_date' => '2013-07-12 05:09:49',
  'post_date_gmt' => '2013-07-12 05:09:49',
  'post_content' => 'Maecenas luctus aliquet risus ac feugiat. Curabitur enim mi, placerat sit amet porttitor ac, mollis lobortis elit. Cras sit amet erat eget dolor varius tristique. Duis eu nisl tortor. Mauris pulvinar metus eget nulla adipiscing consectetur.',
  'post_title' => 'Amy Weaver',
  'post_excerpt' => '',
  'post_name' => 'amy-weaver',
  'post_modified' => '2017-08-21 11:34:52',
  'post_modified_gmt' => '2017-08-21 11:34:52',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=team&#038;p=48',
  'menu_order' => 0,
  'post_type' => 'team',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'team_title' => 'Project Manager',
    'skills' => '[progress_bar label="Project Management" percentage="80"]
[progress_bar label="Marketing" color="#c594da" percentage="58"]
[progress_bar label="Logistics" color="#22d9e5" percentage="69"]',
    'social' => '[team-social label="Twitter" link="http://twitter.com/themify" image="https://themify.me/demo/themes/wp-content/themes/flat/images/twitter.png"]

[team-social label="Facebook" link="http://facebook.com/themify" image="https://themify.me/demo/themes/wp-content/themes/flat/images/facebook.png"]

[team-social label="Pinterest" link="http://pinterest.com/" image="https://themify.me/demo/themes/wp-content/themes/flat/images/pinterest.png"]',
  ),
  'tax_input' => 
  array (
    'team-category' => 'uncategorized',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 51,
  'post_date' => '2008-07-12 05:12:56',
  'post_date_gmt' => '2008-07-12 05:12:56',
  'post_content' => 'Company is founded',
  'post_title' => 'Jul 2008',
  'post_excerpt' => '',
  'post_name' => 'jul-2008',
  'post_modified' => '2017-08-21 11:35:43',
  'post_modified_gmt' => '2017-08-21 11:35:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=51',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'company-timeline',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 52,
  'post_date' => '2008-08-12 05:15:00',
  'post_date_gmt' => '2008-08-12 05:15:00',
  'post_content' => '3 more people joined our team',
  'post_title' => 'Aug 2008',
  'post_excerpt' => '',
  'post_name' => 'aug-2008',
  'post_modified' => '2017-08-21 11:35:41',
  'post_modified_gmt' => '2017-08-21 11:35:41',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=52',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
    'image_width' => '300',
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'company-timeline',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 54,
  'post_date' => '2009-10-12 05:15:41',
  'post_date_gmt' => '2009-10-12 05:15:41',
  'post_content' => 'We moved in the first office space',
  'post_title' => 'Out 2009',
  'post_excerpt' => '',
  'post_name' => 'out-2009',
  'post_modified' => '2017-08-21 11:35:40',
  'post_modified_gmt' => '2017-08-21 11:35:40',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=54',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
    'image_width' => '400',
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'company-timeline',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 56,
  'post_date' => '2010-10-12 05:17:26',
  'post_date_gmt' => '2010-10-12 05:17:26',
  'post_content' => 'Corporate function party',
  'post_title' => 'Dec 2010',
  'post_excerpt' => '',
  'post_name' => 'dec-2010',
  'post_modified' => '2017-08-21 11:35:36',
  'post_modified_gmt' => '2017-08-21 11:35:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=56',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
    'image_width' => '550',
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'company-timeline',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 59,
  'post_date' => '2013-07-12 05:21:54',
  'post_date_gmt' => '2013-07-12 05:21:54',
  'post_content' => '<a class="lightbox" href="http://www.youtube.com/watch?v=hHw6VKKjcpQ"><img class="alignnone size-full wp-image-60" src="https://themify.me/demo/themes/flat/files/2013/07/play.png" alt="play" width="100" height="100" /></a>
Office builder construction begins!',
  'post_title' => 'Jul 2013',
  'post_excerpt' => '',
  'post_name' => 'jul-2013',
  'post_modified' => '2017-08-21 11:35:29',
  'post_modified_gmt' => '2017-08-21 11:35:29',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=59',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'company-timeline',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 192,
  'post_date' => '2002-04-14 23:44:10',
  'post_date_gmt' => '2002-04-14 23:44:10',
  'post_content' => 'Started freelancing.',
  'post_title' => 'Started Freelancing',
  'post_excerpt' => '',
  'post_name' => 'started-freelancing',
  'post_modified' => '2017-08-21 11:35:44',
  'post_modified_gmt' => '2017-08-21 11:35:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=192',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'personal-timeline',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 195,
  'post_date' => '2010-08-14 23:48:02',
  'post_date_gmt' => '2010-08-14 23:48:02',
  'post_content' => 'Launched <a href="https://themify.me">Themify</a>',
  'post_title' => 'Launched Themify',
  'post_excerpt' => '',
  'post_name' => 'launched-themify',
  'post_modified' => '2017-08-21 11:35:38',
  'post_modified_gmt' => '2017-08-21 11:35:38',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=195',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'personal-timeline',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 197,
  'post_date' => '2012-11-14 23:48:42',
  'post_date_gmt' => '2012-11-14 23:48:42',
  'post_content' => 'Themify redesign started

[progress_bar label="Main Wireframe" color="#ffe785" percentage="10"]',
  'post_title' => 'Redesigning Themify',
  'post_excerpt' => '',
  'post_name' => 'redesigning-themify',
  'post_modified' => '2017-08-21 11:35:35',
  'post_modified_gmt' => '2017-08-21 11:35:35',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=197',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'personal-timeline',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 199,
  'post_date' => '2013-07-08 23:54:01',
  'post_date_gmt' => '2013-07-08 23:54:01',
  'post_content' => 'Themify Builder launched',
  'post_title' => 'Launched Themify Builder',
  'post_excerpt' => '',
  'post_name' => 'launched-themify-builder',
  'post_modified' => '2017-08-21 11:35:31',
  'post_modified_gmt' => '2017-08-21 11:35:31',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=199',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
    'image_width' => '400',
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'personal-timeline',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 201,
  'post_date' => '2013-05-14 23:55:18',
  'post_date_gmt' => '2013-05-14 23:55:18',
  'post_content' => 'Themify redesign main layout done

[progress_bar label="Mockup Design" color="#ffe785" percentage="80"]',
  'post_title' => 'Themify Redesign Progress',
  'post_excerpt' => '',
  'post_name' => 'themify-redesign-progress',
  'post_modified' => '2017-08-21 11:35:33',
  'post_modified_gmt' => '2017-08-21 11:35:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=timeline&#038;p=201',
  'menu_order' => 0,
  'post_type' => 'timeline',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'timeline-category' => 'personal-timeline',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 12,
  'post_date' => '2013-07-12 03:03:52',
  'post_date_gmt' => '2013-07-12 03:03:52',
  'post_content' => 'Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop\'s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.',
  'post_title' => 'Mike Canlas',
  'post_excerpt' => '',
  'post_name' => 'mike-canlas',
  'post_modified' => '2017-08-21 11:36:26',
  'post_modified_gmt' => '2017-08-21 11:36:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=testimonial&#038;p=12',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
    'testimonial_name' => 'Mike Canlas',
    'testimonial_title' => 'Owner',
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'uncategorized',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 20,
  'post_date' => '2013-07-12 04:13:47',
  'post_date_gmt' => '2013-07-12 04:13:47',
  'post_content' => 'Rravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. This is Photoshop’s version of Lorem Ipsum. Llorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.',
  'post_title' => 'Amanda Elric',
  'post_excerpt' => '',
  'post_name' => 'amanda-elric',
  'post_modified' => '2017-08-21 11:36:24',
  'post_modified_gmt' => '2017-08-21 11:36:24',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=testimonial&#038;p=20',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
    'testimonial_name' => 'Amanda Elric',
    'testimonial_title' => 'Manager, Themify',
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'uncategorized',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 22,
  'post_date' => '2013-07-12 04:28:32',
  'post_date_gmt' => '2013-07-12 04:28:32',
  'post_content' => 'Maecenas in orci nunc. Curabitur velit sapien, mollis vel aliquam et, dignissim consequat eros. Curabitur egestas quam dapibus arcu egestas mollis.',
  'post_title' => 'Diana Jones',
  'post_excerpt' => '',
  'post_name' => 'diana-jones',
  'post_modified' => '2017-08-21 11:36:23',
  'post_modified_gmt' => '2017-08-21 11:36:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=testimonial&#038;p=22',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
    'testimonial_name' => 'Diana Jones',
    'testimonial_title' => 'CEO, Nice Company',
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'uncategorized',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2097,
  'post_date' => '2008-06-11 21:26:15',
  'post_date_gmt' => '2008-06-11 21:26:15',
  'post_content' => 'Fusce ultrices placerat sem at rutrum. Etiam bibendum ac sapien in vulputate. Maecenas commodo elementum gravida. Vivamus odio odio, pulvinar vel leo id, fringilla ullamcorper odio.',
  'post_title' => 'Carl Schmidt',
  'post_excerpt' => '',
  'post_name' => 'carl-schmidt',
  'post_modified' => '2017-08-21 11:36:38',
  'post_modified_gmt' => '2017-08-21 11:36:38',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?post_type=testimonial&#038;p=59',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'team',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2098,
  'post_date' => '2008-06-11 21:28:42',
  'post_date_gmt' => '2008-06-11 21:28:42',
  'post_content' => 'Sed volutpat tristique metus eget suscipit. Donec aliquam eget purus id cursus. Integer ut arcu scelerisque, porttitor eros nec, placerat eros.',
  'post_title' => 'Clara Ray',
  'post_excerpt' => '',
  'post_name' => 'clara-ray',
  'post_modified' => '2017-08-21 11:36:37',
  'post_modified_gmt' => '2017-08-21 11:36:37',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?post_type=testimonial&#038;p=61',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'team',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2099,
  'post_date' => '2008-06-11 21:31:55',
  'post_date_gmt' => '2008-06-11 21:31:55',
  'post_content' => 'Maecenas in orci nunc. Curabitur velit sapien, mollis vel aliquam et, dignissim consequat eros. Curabitur egestas quam dapibus arcu egestas mollis.',
  'post_title' => 'Diana Jones',
  'post_excerpt' => '',
  'post_name' => 'diana-jones-2',
  'post_modified' => '2017-08-21 11:36:36',
  'post_modified_gmt' => '2017-08-21 11:36:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?post_type=testimonial&#038;p=63',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'team',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2100,
  'post_date' => '2008-06-11 21:33:02',
  'post_date_gmt' => '2008-06-11 21:33:02',
  'post_content' => 'Aliquam euismod aliquet nunc, mollis consectetur sapien congue eu. Pellentesque erat mauris, varius non posuere sit amet, tempor ac velit.',
  'post_title' => 'Patricia Wolf',
  'post_excerpt' => '',
  'post_name' => 'patricia-wolf',
  'post_modified' => '2017-08-21 11:36:34',
  'post_modified_gmt' => '2017-08-21 11:36:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?post_type=testimonial&#038;p=65',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'team',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1589,
  'post_date' => '2008-11-02 19:39:01',
  'post_date_gmt' => '2008-11-02 19:39:01',
  'post_content' => 'Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu. Mauris consequat rhoncus dolor id sagittis. Cras tortor elit, aliquet quis tincidunt eget, dignissim non tortor.',
  'post_title' => 'Extremely Happy',
  'post_excerpt' => '',
  'post_name' => 'extremely-happy',
  'post_modified' => '2017-08-21 11:36:32',
  'post_modified_gmt' => '2017-08-21 11:36:32',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=testimonial&#038;p=27',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'testimonials',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1590,
  'post_date' => '2008-11-09 20:28:43',
  'post_date_gmt' => '2008-11-09 20:28:43',
  'post_content' => 'Nam nunc lectus, congue non egestas quis, condimentum ut arcu. Nulla placerat, tortor non egestas rutrum, mi turpis adipiscing dui, et mollis turpis tortor vel orci. Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu.',
  'post_title' => 'Super Awesome!',
  'post_excerpt' => '',
  'post_name' => 'super-awesome',
  'post_modified' => '2017-08-21 11:36:31',
  'post_modified_gmt' => '2017-08-21 11:36:31',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=testimonial&#038;p=66',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'testimonials',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1591,
  'post_date' => '2008-11-19 19:58:11',
  'post_date_gmt' => '2008-11-19 19:58:11',
  'post_content' => 'Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.',
  'post_title' => 'Best Services in Town!',
  'post_excerpt' => '',
  'post_name' => 'best-services-in-town',
  'post_modified' => '2017-08-21 11:36:29',
  'post_modified_gmt' => '2017-08-21 11:36:29',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=testimonial&#038;p=1152',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'testimonials',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1592,
  'post_date' => '2008-11-19 19:59:53',
  'post_date_gmt' => '2008-11-19 19:59:53',
  'post_content' => 'Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla. Fusce ut sem est. In eu sagittis felis. In gravida arcu ut neque ornare vitae rutrum tu. Cras a fringilla nunc. Suspendisse volutpat, eros cong rpis vehicula.',
  'post_title' => 'Exceeded Our Expectation',
  'post_excerpt' => '',
  'post_name' => 'exceeded-our-expectation',
  'post_modified' => '2017-08-21 11:36:28',
  'post_modified_gmt' => '2017-08-21 11:36:28',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=testimonial&#038;p=1156',
  'menu_order' => 0,
  'post_type' => 'testimonial',
  'meta_input' => 
  array (
    'testimonial_name' => 'Vanissa',
    'testimonial_title' => 'Manager',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'testimonial-category' => 'testimonials',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 63,
  'post_date' => '2013-07-12 05:54:32',
  'post_date_gmt' => '2013-07-12 05:54:32',
  'post_content' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus accumsan consectetur erat ac sodales. Mauris rhoncus dolor sed ante vulputate, ut mollis augue semper. Etiam eleifend turpis lorem, in sollicitudin enim cursus in. Donec at interdum felis. Cras tristique eget ante sit amet iaculis. Aliquam eu egestas nulla.',
  'post_title' => 'Red Rose',
  'post_excerpt' => '',
  'post_name' => 'red-rose',
  'post_modified' => '2017-08-21 11:37:43',
  'post_modified_gmt' => '2017-08-21 11:37:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=63',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'gallery_shortcode' => '[gallery ids="143,142,144"]',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 65,
  'post_date' => '2013-07-12 05:58:27',
  'post_date_gmt' => '2013-07-12 05:58:27',
  'post_content' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus accumsan consectetur erat ac sodales. Mauris rhoncus dolor sed ante vulputate, ut mollis augue semper. Etiam eleifend turpis lorem, in sollicitudin enim cursus in. Donec at interdum felis. Cras tristique eget ante sit amet iaculis. Aliquam eu egestas nulla.',
  'post_title' => 'Watercolor',
  'post_excerpt' => '',
  'post_name' => 'watercolor',
  'post_modified' => '2017-08-21 11:37:42',
  'post_modified_gmt' => '2017-08-21 11:37:42',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=65',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'gallery_shortcode' => '[gallery ids="69,66,67"]',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 71,
  'post_date' => '2013-07-08 06:06:17',
  'post_date_gmt' => '2013-07-08 06:06:17',
  'post_content' => 'Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean porta id orci eu sodales. Ut facilisis nisi hendrerit, pharetra lorem non, dignissim eros. Cras elit nisi, malesuada viverra risus molestie, luctus bibendum nisi. Nulla id ipsum scelerisque, fringilla purus ac, sollicitudin tellus. Quisque convallis lorem ac turpis rhoncus dignissim. Donec pulvinar, sapien id adipiscing faucibus, metus eros tincidunt quam, feugiat interdum ante risus quis nunc.',
  'post_title' => 'TV Commercial',
  'post_excerpt' => '',
  'post_name' => 'tv-commercial',
  'post_modified' => '2017-08-21 11:37:52',
  'post_modified_gmt' => '2017-08-21 11:37:52',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=71',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'videos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 73,
  'post_date' => '2013-07-09 06:09:48',
  'post_date_gmt' => '2013-07-09 06:09:48',
  'post_content' => 'Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Aenean porta id orci eu sodales. Ut facilisis nisi hendrerit, pharetra lorem non, dignissim eros. Cras elit nisi, malesuada viverra risus molestie, luctus bibendum nisi. Nulla id ipsum scelerisque, fringilla purus ac, sollicitudin tellus. Quisque convallis lorem ac turpis rhoncus dignissim. Donec pulvinar, sapien id adipiscing faucibus, metus eros tincidunt quam, feugiat interdum ante risus quis nunc.',
  'post_title' => 'Summer Vacation',
  'post_excerpt' => '',
  'post_name' => 'summer-vacation',
  'post_modified' => '2017-08-21 11:37:50',
  'post_modified_gmt' => '2017-08-21 11:37:50',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=73',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'vintage',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 157,
  'post_date' => '2013-07-12 23:26:37',
  'post_date_gmt' => '2013-07-12 23:26:37',
  'post_content' => 'Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo.',
  'post_title' => 'Dark Gallery',
  'post_excerpt' => '',
  'post_name' => 'dark-gallery',
  'post_modified' => '2017-08-21 11:37:39',
  'post_modified_gmt' => '2017-08-21 11:37:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=157',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'gallery_shortcode' => '[gallery ids="158,159,160"]',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured, photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 151,
  'post_date' => '2013-07-11 23:16:09',
  'post_date_gmt' => '2013-07-11 23:16:09',
  'post_content' => 'Donec at interdum felis. Cras tristique eget ante sit amet iaculis. Aliquam eu egestas nulla. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus accumsan consectetur erat ac sodales. Mauris rhoncus dolor sed ante vulputate, ut mollis augue semper. Etiam eleifend turpis lorem, in sollicitudin enim cursus in.',
  'post_title' => 'Black & White',
  'post_excerpt' => '',
  'post_name' => 'black-white',
  'post_modified' => '2017-08-21 11:37:45',
  'post_modified_gmt' => '2017-08-21 11:37:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=151',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'gallery_shortcode' => '[gallery link="file" ids="152,154,155"]',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured, photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 161,
  'post_date' => '2013-07-10 23:28:30',
  'post_date_gmt' => '2013-07-10 23:28:30',
  'post_content' => 'Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida.',
  'post_title' => 'On The Ride',
  'post_excerpt' => '',
  'post_name' => 'on-the-ride',
  'post_modified' => '2017-08-21 11:37:48',
  'post_modified_gmt' => '2017-08-21 11:37:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=161',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 165,
  'post_date' => '2013-07-10 23:45:57',
  'post_date_gmt' => '2013-07-10 23:45:57',
  'post_content' => 'Curabitur venenatis vehicula mattis. Nunc eleifend consectetur odio sit amet viverra. Ut euismod ligula eu tellus interdum mattis ac eu nulla. Phasellus cursus, lacus quis convallis aliquet, dolor urna ullamcorper mi, eget dapibus velit est vitae nisi.',
  'post_title' => 'Red Rose',
  'post_excerpt' => '',
  'post_name' => 'red-rose-2',
  'post_modified' => '2017-08-21 11:37:47',
  'post_modified_gmt' => '2017-08-21 11:37:47',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?post_type=portfolio&#038;p=165',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 250,
  'post_date' => '2008-01-25 19:20:02',
  'post_date_gmt' => '2008-01-25 19:20:02',
  'post_content' => 'Nulla ut mi risus. Phasellus pretium diam in risus vestibulum elementum. Donec quis ipsum sem, in elementum metus. Mauris sagittis cursus felis vitae mattis. Donec adipiscing consequat velit vitae convallis. Proin sit amet lectus non enim lobortis aliquet. Donec sit amet magna vitae ante pellentesque adipiscing.',
  'post_title' => 'In The Spotlight',
  'post_excerpt' => 'Fusce fermentum ante turpis, et congue',
  'post_name' => 'in-the-spotlight',
  'post_modified' => '2017-08-21 11:38:11',
  'post_modified_gmt' => '2017-08-21 11:38:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/metro/?post_type=portfolio&#038;p=250',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 274,
  'post_date' => '2008-01-25 21:53:37',
  'post_date_gmt' => '2008-01-25 21:53:37',
  'post_content' => 'Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu.',
  'post_title' => 'Photo Project',
  'post_excerpt' => 'Pellentesque diam velit, luctus vel porta',
  'post_name' => 'photo-project',
  'post_modified' => '2017-08-21 11:38:10',
  'post_modified_gmt' => '2017-08-21 11:38:10',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/metro/?post_type=portfolio&#038;p=274',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 283,
  'post_date' => '2008-01-25 22:15:36',
  'post_date_gmt' => '2008-01-25 22:15:36',
  'post_content' => 'Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum.',
  'post_title' => 'Another Photo Shot',
  'post_excerpt' => 'Lorem ipsum dolor sit amet',
  'post_name' => 'another-photo-shot',
  'post_modified' => '2017-08-21 11:38:08',
  'post_modified_gmt' => '2017-08-21 11:38:08',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/metro/?post_type=portfolio&#038;p=283',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 288,
  'post_date' => '2008-01-25 22:22:08',
  'post_date_gmt' => '2008-01-25 22:22:08',
  'post_content' => 'In eu sagittis felis. In gravida arcu ut neque ornare vitae rutrum turpis vehicula. Nunc ultrices sem mollis metus rutrum non malesuada metus fermentum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Pellentesque interdum rutrum quam.',
  'post_title' => 'Just a Model',
  'post_excerpt' => 'Fusce fermentum ante turpis, et congue',
  'post_name' => 'just-a-model',
  'post_modified' => '2017-08-21 11:38:06',
  'post_modified_gmt' => '2017-08-21 11:38:06',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/metro/?post_type=portfolio&#038;p=288',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 291,
  'post_date' => '2008-01-25 22:25:29',
  'post_date_gmt' => '2008-01-25 22:25:29',
  'post_content' => 'The congue non egestas quis, condime estibulum congue nisl magna. Ut vulputate odio id dui convallis in adipiscing libero condimentum. Nunc et pharetra enim. Praesent pharetra, neque et luctus tempor, leo sapien faucibus leo, a dignissim turpis ipsum sed libero. Sed sed luctus purus. Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus ntu.',
  'post_title' => 'In The Wood',
  'post_excerpt' => 'Morbi sed arcu at tortor ultricies',
  'post_name' => 'in-the-wood',
  'post_modified' => '2017-08-21 11:38:05',
  'post_modified_gmt' => '2017-08-21 11:38:05',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/metro/?post_type=portfolio&#038;p=291',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 292,
  'post_date' => '2008-01-25 22:26:46',
  'post_date_gmt' => '2008-01-25 22:26:46',
  'post_content' => 'Praesent pharetra, neque et luctus tempor estibulum congue nisl magna. Ut vulputate odio id dui convallis in adipiscing libero condimentum. Nunc et pharetra enim, leo sapien faucibus leo, a dignissim turpis ipsum sed libero. Sed sed luctus purus. Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentu.',
  'post_title' => 'Late Arrival',
  'post_excerpt' => 'Quisque ornare vestibulum nibh in lacinia',
  'post_name' => 'late-arrival',
  'post_modified' => '2017-08-21 11:38:03',
  'post_modified_gmt' => '2017-08-21 11:38:03',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/metro/?post_type=portfolio&#038;p=292',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 293,
  'post_date' => '2008-01-25 22:27:53',
  'post_date_gmt' => '2008-01-25 22:27:53',
  'post_content' => 'Praesent pharetra, neque et luctus tempor. Vestibulum congue nisl magna. Ut vulputate odio id dui convallis in adipiscing libero condimentum. Nunc et pharetra enim. Praesent pharetra, neque et luctus tempor, leo sapien faucibus leo, a dignissim turpis ipsum sed libero. Sed sed luctus purus. Aliquam faucibus turpis at libero consectetur euismod.',
  'post_title' => 'Summer Rain',
  'post_excerpt' => 'Vestibulum rutrum, metus vitae pretium',
  'post_name' => 'summer-rain',
  'post_modified' => '2017-08-21 11:38:01',
  'post_modified_gmt' => '2017-08-21 11:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/metro/?post_type=portfolio&#038;p=293',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1489,
  'post_date' => '2008-09-18 20:49:59',
  'post_date_gmt' => '2008-09-18 20:49:59',
  'post_content' => 'Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentum ut arcu. Nulla placerat, tortor non egestas rutrum, mi turpis adipiscing dui, et mollis turpis tortor vel orci. Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu. Mauris consequat rhoncus dolor id sagittis. Cras tortor elit, aliquet quis tincidunt eget, dignissim non tortor.',
  'post_title' => 'Just a Photo',
  'post_excerpt' => '',
  'post_name' => 'just-a-photo',
  'post_modified' => '2017-08-21 11:37:59',
  'post_modified_gmt' => '2017-08-21 11:37:59',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=portfolio&#038;p=1089',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured, photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1570,
  'post_date' => '2008-09-18 20:51:12',
  'post_date_gmt' => '2008-09-18 20:51:12',
  'post_content' => 'Praesent pharetra, neque et luctus tempor, leo sapien faucibus leo, a dignissim turpis ipsum sed libero. Sed sed luctus purus. Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentum ut arcu. Nulla placerat, tortor non egestas rutrum, mi turpis adipiscing dui, et mollis turpis tortor vel orci. Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu.',
  'post_title' => 'Photo Two',
  'post_excerpt' => 'Praesent pharetra, neque et luctus tempor, leo sapien.',
  'post_name' => 'photo-two',
  'post_modified' => '2017-08-21 11:37:58',
  'post_modified_gmt' => '2017-08-21 11:37:58',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=portfolio&#038;p=1091',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1571,
  'post_date' => '2008-09-18 20:52:05',
  'post_date_gmt' => '2008-09-18 20:52:05',
  'post_content' => 'Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla. Fusce ut sem est. In eu sagittis felis. In gravida arcu ut neque ornare vitae rutrum turpis vehicula. Nunc ultrices sem mollis metus rutrum non malesuada metus fermentum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Pellentesque interdum rutrum quam, a pharetra est pulvinar ac. Vestibulum congue nisl magna.',
  'post_title' => 'Shot Number Three',
  'post_excerpt' => 'Aliquam metus diam, mattis fringilla adipiscing at',
  'post_name' => 'shot-number-three',
  'post_modified' => '2017-08-21 11:37:55',
  'post_modified_gmt' => '2017-08-21 11:37:55',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=portfolio&#038;p=1093',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'featured',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 1572,
  'post_date' => '2008-09-18 20:52:37',
  'post_date_gmt' => '2008-09-18 20:52:37',
  'post_content' => 'Ut euismod ligula eu tellus interdum mattis ac eu nulla. Phasellus cursus, lacus quis convallis aliquet, dolor urna ullamcorper mi, eget dapibus velit est vitae nisi. Aliquam erat nulla, sodales at imperdiet vitae, convallis vel dui. Sed ultrices felis ut justo suscipit vestibulum. Pellentesque nisl nisi, vehicula vitae hendrerit vel, mattis eget mauris. Donec consequat eros eget lectus dictum sit amet ultrices neque sodales. Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla. Fusce ut sem est. In eu sagittis felis.',
  'post_title' => 'Beautiful Shot',
  'post_excerpt' => 'Ut euismod ligula eu tellus interdum mattis ac eu nulla.',
  'post_name' => 'beautiful-shot',
  'post_modified' => '2017-08-21 11:37:54',
  'post_modified_gmt' => '2017-08-21 11:37:54',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/agency/?post_type=portfolio&#038;p=1095',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'media_type' => 'slider',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2216,
  'post_date' => '2013-11-11 19:46:04',
  'post_date_gmt' => '2013-11-11 19:46:04',
  'post_content' => '',
  'post_title' => 'Top',
  'post_excerpt' => '',
  'post_name' => 'home',
  'post_modified' => '2015-01-26 13:52:26',
  'post_modified_gmt' => '2015-01-26 13:52:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2216',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2216',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2215,
  'post_date' => '2013-11-11 19:46:04',
  'post_date_gmt' => '2013-11-11 19:46:04',
  'post_content' => '',
  'post_title' => 'Portfolio',
  'post_excerpt' => '',
  'post_name' => 'discover',
  'post_modified' => '2015-01-26 13:52:26',
  'post_modified_gmt' => '2015-01-26 13:52:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2215',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2215',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#portfolio',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2220,
  'post_date' => '2013-11-11 19:46:04',
  'post_date_gmt' => '2013-11-11 19:46:04',
  'post_content' => '',
  'post_title' => 'Highlights',
  'post_excerpt' => '',
  'post_name' => 'history',
  'post_modified' => '2015-01-26 13:52:26',
  'post_modified_gmt' => '2015-01-26 13:52:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2220',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2220',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#highlight',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2219,
  'post_date' => '2013-11-11 19:46:04',
  'post_date_gmt' => '2013-11-11 19:46:04',
  'post_content' => '',
  'post_title' => 'Team',
  'post_excerpt' => '',
  'post_name' => 'team',
  'post_modified' => '2015-01-26 13:52:26',
  'post_modified_gmt' => '2015-01-26 13:52:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2219',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2219',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#team',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2247,
  'post_date' => '2013-11-11 20:47:26',
  'post_date_gmt' => '2013-11-11 20:47:26',
  'post_content' => '',
  'post_title' => 'Testimonials',
  'post_excerpt' => '',
  'post_name' => 'testimonials',
  'post_modified' => '2015-01-26 13:52:26',
  'post_modified_gmt' => '2015-01-26 13:52:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2247',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2247',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#testimonial-post-type',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2248,
  'post_date' => '2013-11-11 20:47:26',
  'post_date_gmt' => '2013-11-11 20:47:26',
  'post_content' => '',
  'post_title' => 'Blog',
  'post_excerpt' => '',
  'post_name' => 'blog',
  'post_modified' => '2015-01-26 13:52:26',
  'post_modified_gmt' => '2015-01-26 13:52:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2248',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2248',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#blog-3',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2221,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => '',
  'post_title' => 'More',
  'post_excerpt' => '',
  'post_name' => 'more',
  'post_modified' => '2015-01-26 13:52:26',
  'post_modified_gmt' => '2015-01-26 13:52:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2221',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2221',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2222,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2222',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2222',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2221',
    '_menu_item_object_id' => '2172',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2223,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2223',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 2172,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2223',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2222',
    '_menu_item_object_id' => '2212',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2224,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2224',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 2172,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2224',
  'menu_order' => 10,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2222',
    '_menu_item_object_id' => '2210',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2225,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2225',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2225',
  'menu_order' => 11,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2221',
    '_menu_item_object_id' => '2156',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2226,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2226',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 2156,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2226',
  'menu_order' => 12,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2225',
    '_menu_item_object_id' => '2208',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2227,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2227',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 2156,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2227',
  'menu_order' => 13,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2225',
    '_menu_item_object_id' => '2205',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2228,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2228',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 2156,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2228',
  'menu_order' => 14,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2225',
    '_menu_item_object_id' => '2203',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2229,
  'post_date' => '2013-11-11 20:06:08',
  'post_date_gmt' => '2013-11-11 20:06:08',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2229',
  'post_modified' => '2015-01-26 13:52:27',
  'post_modified_gmt' => '2015-01-26 13:52:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/flat/?p=2229',
  'menu_order' => 15,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2221',
    '_menu_item_object_id' => '2132',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'single-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}


function themify_import_get_term_id_from_slug( $slug ) {
	$menu = get_term_by( "slug", $slug, "nav_menu" );
	return is_wp_error( $menu ) ? 0 : (int) $menu->term_id;
}

	$widgets = get_option( "widget_search" );
$widgets[1002] = array (
  'title' => '',
);
update_option( "widget_search", $widgets );

$widgets = get_option( "widget_recent-posts" );
$widgets[1003] = array (
  'title' => '',
  'number' => 5,
);
update_option( "widget_recent-posts", $widgets );

$widgets = get_option( "widget_recent-comments" );
$widgets[1004] = array (
  'title' => '',
  'number' => 5,
);
update_option( "widget_recent-comments", $widgets );

$widgets = get_option( "widget_archives" );
$widgets[1005] = array (
  'title' => '',
  'count' => 0,
  'dropdown' => 0,
);
update_option( "widget_archives", $widgets );

$widgets = get_option( "widget_categories" );
$widgets[1006] = array (
  'title' => '',
  'count' => 0,
  'hierarchical' => 0,
  'dropdown' => 0,
);
update_option( "widget_categories", $widgets );

$widgets = get_option( "widget_meta" );
$widgets[1007] = array (
  'title' => '',
);
update_option( "widget_meta", $widgets );

$widgets = get_option( "widget_themify-social-links" );
$widgets[1008] = array (
  'title' => '',
  'show_link_name' => NULL,
  'open_new_window' => NULL,
  'thumb_width' => '',
  'thumb_height' => '',
  'icon_size' => 'icon-large',
  'orientation' => 'horizontal',
);
update_option( "widget_themify-social-links", $widgets );



$sidebars_widgets = array (
  'sidebar-main' => 
  array (
    0 => 'search-1002',
    1 => 'recent-posts-1003',
    2 => 'recent-comments-1004',
    3 => 'archives-1005',
    4 => 'categories-1006',
    5 => 'meta-1007',
  ),
  'social-widget' => 
  array (
    0 => 'themify-social-links-1008',
  ),
); 
update_option( "sidebars_widgets", $sidebars_widgets );

$menu_locations = array();
set_theme_mod( "nav_menu_locations", $menu_locations );


$homepage = get_posts( array( 'name' => 'features', 'post_type' => 'page' ) );
			if( is_array( $homepage ) && ! empty( $homepage ) ) {
				update_option( 'show_on_front', 'page' );
				update_option( 'page_on_front', $homepage[0]->ID );
			}
			
	ob_start(); ?>a:85:{s:16:"setting-page_404";s:1:"0";s:21:"setting-webfonts_list";s:11:"recommended";s:22:"setting-default_layout";s:8:"sidebar1";s:27:"setting-default_post_layout";s:9:"list-post";s:30:"setting-default_layout_display";s:7:"content";s:25:"setting-default_more_text";s:4:"More";s:21:"setting-index_orderby";s:4:"date";s:19:"setting-index_order";s:4:"DESC";s:31:"setting-image_post_feature_size";s:5:"blank";s:32:"setting-default_page_post_layout";s:8:"sidebar1";s:38:"setting-image_post_single_feature_size";s:5:"blank";s:27:"setting-default_page_layout";s:8:"sidebar1";s:38:"setting-default_portfolio_index_layout";s:12:"sidebar-none";s:39:"setting-default_portfolio_index_display";s:4:"none";s:50:"setting-default_portfolio_index_post_meta_category";s:3:"yes";s:41:"setting-default_portfolio_index_post_date";s:3:"yes";s:51:"setting-default_portfolio_single_post_meta_category";s:3:"yes";s:49:"setting-default_portfolio_single_image_post_width";s:3:"640";s:50:"setting-default_portfolio_single_image_post_height";s:3:"640";s:22:"themify_portfolio_slug";s:7:"project";s:34:"setting-default_team_single_layout";s:12:"sidebar-none";s:17:"themify_team_slug";s:4:"team";s:53:"setting-customizer_responsive_design_tablet_landscape";s:4:"1024";s:43:"setting-customizer_responsive_design_tablet";s:3:"768";s:43:"setting-customizer_responsive_design_mobile";s:3:"680";s:33:"setting-mobile_menu_trigger_point";s:4:"1200";s:24:"setting-gallery_lightbox";s:8:"lightbox";s:26:"setting-page_builder_cache";s:2:"on";s:27:"setting-script_minification";s:7:"disable";s:27:"setting-page_builder_expiry";s:1:"2";s:19:"setting-entries_nav";s:8:"numbered";s:33:"setting-portfolio_slider_autoplay";s:4:"4000";s:31:"setting-portfolio_slider_effect";s:5:"slide";s:41:"setting-portfolio_slider_transition_speed";s:3:"500";s:35:"setting-testimonial_slider_autoplay";s:4:"4000";s:33:"setting-testimonial_slider_effect";s:5:"slide";s:43:"setting-testimonial_slider_transition_speed";s:3:"500";s:22:"setting-footer_widgets";s:17:"footerwidget-3col";s:27:"setting-global_feature_size";s:5:"large";s:22:"setting-link_icon_type";s:10:"image-icon";s:32:"setting-link_type_themify-link-0";s:10:"image-icon";s:33:"setting-link_title_themify-link-0";s:7:"Twitter";s:32:"setting-link_link_themify-link-0";s:26:"http://twitter.com/themify";s:31:"setting-link_img_themify-link-0";s:77:"https://themify.me/demo/themes/flat/wp-content/themes/flat/images/twitter.png";s:32:"setting-link_type_themify-link-1";s:10:"image-icon";s:33:"setting-link_title_themify-link-1";s:8:"Facebook";s:32:"setting-link_link_themify-link-1";s:32:"https://www.facebook.com/themify";s:31:"setting-link_img_themify-link-1";s:78:"https://themify.me/demo/themes/flat/wp-content/themes/flat/images/facebook.png";s:32:"setting-link_type_themify-link-2";s:10:"image-icon";s:33:"setting-link_title_themify-link-2";s:6:"Google";s:32:"setting-link_link_themify-link-2";s:24:"https://plus.google.com/";s:31:"setting-link_img_themify-link-2";s:81:"https://themify.me/demo/themes/flat/wp-content/themes/flat/images/google-plus.png";s:32:"setting-link_type_themify-link-3";s:10:"image-icon";s:33:"setting-link_title_themify-link-3";s:7:"YouTube";s:32:"setting-link_link_themify-link-3";s:18:"http://youtube.com";s:31:"setting-link_img_themify-link-3";s:77:"https://themify.me/demo/themes/flat/wp-content/themes/flat/images/youtube.png";s:32:"setting-link_type_themify-link-4";s:10:"image-icon";s:33:"setting-link_title_themify-link-4";s:9:"Pinterest";s:32:"setting-link_link_themify-link-4";s:21:"http://pinterest.com/";s:31:"setting-link_img_themify-link-4";s:79:"https://themify.me/demo/themes/flat/wp-content/themes/flat/images/pinterest.png";s:32:"setting-link_type_themify-link-5";s:9:"font-icon";s:33:"setting-link_title_themify-link-5";s:7:"Twitter";s:32:"setting-link_link_themify-link-5";s:26:"http://twitter.com/themify";s:33:"setting-link_ficon_themify-link-5";s:10:"fa-twitter";s:32:"setting-link_type_themify-link-6";s:9:"font-icon";s:33:"setting-link_title_themify-link-6";s:8:"Facebook";s:32:"setting-link_link_themify-link-6";s:27:"http://facebook.com/themify";s:33:"setting-link_ficon_themify-link-6";s:11:"fa-facebook";s:32:"setting-link_type_themify-link-7";s:9:"font-icon";s:33:"setting-link_title_themify-link-7";s:7:"Google+";s:32:"setting-link_link_themify-link-7";s:27:"https://plus.google.com/‎";s:33:"setting-link_ficon_themify-link-7";s:14:"fa-google-plus";s:32:"setting-link_type_themify-link-8";s:9:"font-icon";s:33:"setting-link_title_themify-link-8";s:7:"YouTube";s:32:"setting-link_link_themify-link-8";s:37:"http://www.youtube.com/user/themifyme";s:33:"setting-link_ficon_themify-link-8";s:10:"fa-youtube";s:32:"setting-link_type_themify-link-9";s:9:"font-icon";s:33:"setting-link_title_themify-link-9";s:9:"Pinterest";s:32:"setting-link_link_themify-link-9";s:20:"http://pinterest.com";s:33:"setting-link_ficon_themify-link-9";s:12:"fa-pinterest";s:22:"setting-link_field_ids";s:341:"{"themify-link-0":"themify-link-0","themify-link-1":"themify-link-1","themify-link-2":"themify-link-2","themify-link-3":"themify-link-3","themify-link-4":"themify-link-4","themify-link-5":"themify-link-5","themify-link-6":"themify-link-6","themify-link-7":"themify-link-7","themify-link-8":"themify-link-8","themify-link-9":"themify-link-9"}";s:23:"setting-link_field_hash";s:2:"10";s:30:"setting-page_builder_is_active";s:6:"enable";s:46:"setting-page_builder_animation_parallax_scroll";s:6:"mobile";s:4:"skin";s:83:"https://themify.me/demo/themes/flat/wp-content/themes/flat/themify/img/non-skin.gif";}<?php $themify_data = unserialize( ob_get_clean() );

	// fix the weird way "skin" is saved
	if( isset( $themify_data['skin'] ) ) {
		$parsed_skin = parse_url( $themify_data['skin'], PHP_URL_PATH );
		$basedir_skin = basename( dirname( $parsed_skin ) );
		$themify_data['skin'] = trailingslashit( get_template_directory_uri() ) . 'skins/' . $basedir_skin . '/style.css';
	}

	themify_set_data( $themify_data );
	
}
themify_do_demo_import();